@@ -46,6 +46,7 @@
 #include "misc.h"
 #include "urlhandler.h"
 
+#include "gmentrydialog.h"
 #include "gconf_widgets_extensions.h"
 
 
@@ -118,11 +119,6 @@ void
 transfer_call_cb (GtkWidget* widget,
 		  gpointer data)
 {
-  GtkWidget *transfer_call_popup = NULL;
-  GtkWidget *hbox = NULL;
-  GtkWidget *label = NULL;
-  GtkWidget *entry = NULL;
-
   GMH323EndPoint *endpoint = NULL;
   GmWindow *gw = NULL;
   GMURL url;
@@ -130,70 +126,48 @@ transfer_call_cb (GtkWidget* widget,
   char *gconf_forward_value = NULL;
   gint answer = 0;
   
-  GConfClient *client = NULL;
-
-  client = gconf_client_get_default ();
   endpoint = GnomeMeeting::Process ()->Endpoint ();
   gw = GnomeMeeting::Process ()->GetMainWindow ();
 
-  transfer_call_popup =
-        gtk_dialog_new_with_buttons (_("Edit the contact information"), 
-				     NULL, GTK_DIALOG_MODAL,
-				     GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT,
-				     _("_Transfer Call"), GTK_RESPONSE_ACCEPT,
-				     NULL);
+  gw->transfer_call_popup = gm_entry_dialog_new (_("Transfer call to:"),
+						 _("Transfer"));
+
   if (!data) {
 
-    gtk_window_set_transient_for (GTK_WINDOW (transfer_call_popup),
+    gtk_window_set_transient_for (GTK_WINDOW (gw->transfer_call_popup),
 				  GTK_WINDOW (gm));
     gconf_forward_value =
-      gconf_client_get_string (GCONF_CLIENT (client),
-			       CALL_FORWARDING_KEY "forward_host",
-			       NULL);
+      gconf_get_string (CALL_FORWARDING_KEY "forward_host");
   }
   else {
     
-    gtk_window_set_transient_for (GTK_WINDOW (transfer_call_popup),
+    gtk_window_set_transient_for (GTK_WINDOW (gw->transfer_call_popup),
 				  GTK_WINDOW (gw->ldap_window));
     gconf_forward_value = g_strdup ((gchar *) data);
   }
   
-  gtk_dialog_set_default_response (GTK_DIALOG (transfer_call_popup),
+  gtk_dialog_set_default_response (GTK_DIALOG (gw->transfer_call_popup),
 				   GTK_RESPONSE_ACCEPT);
   
-  label = gtk_label_new (_("Forward call to:"));
-  hbox = gtk_hbox_new (0, 0);
-  
-  gtk_box_pack_start (GTK_BOX 
-		      (GTK_DIALOG (transfer_call_popup)->vbox), 
-		      hbox, TRUE, TRUE, 10);
-    
-  entry = gtk_entry_new ();
   if (gconf_forward_value && strcmp (gconf_forward_value, ""))
-    gtk_entry_set_text (GTK_ENTRY (entry), gconf_forward_value);
+    gm_entry_dialog_set_text (GM_ENTRY_DIALOG (gw->transfer_call_popup),
+			      gconf_forward_value);
   else
-    gtk_entry_set_text (GTK_ENTRY (entry),
-			(const char *) url.GetDefaultURL ());
+    gm_entry_dialog_set_text (GM_ENTRY_DIALOG (gw->transfer_call_popup),
+			      (const char *) url.GetDefaultURL ());
+
   g_free (gconf_forward_value);
-  gtk_entry_set_activates_default (GTK_ENTRY (entry), true);
-  
   gconf_forward_value = NULL;
+  
+  gtk_widget_show_all (gw->transfer_call_popup);
 
-  gtk_box_pack_start (GTK_BOX (hbox), 
-		      label, TRUE, TRUE, 10);
-  gtk_box_pack_start (GTK_BOX (hbox), 
-		      entry, TRUE, TRUE, 10);
-
-  gtk_window_set_modal (GTK_WINDOW (transfer_call_popup), TRUE);
-
-  gtk_widget_show_all (transfer_call_popup);
-
-  answer = gtk_dialog_run (GTK_DIALOG (transfer_call_popup));
+  answer = gtk_dialog_run (GTK_DIALOG (gw->transfer_call_popup));
   switch (answer) {
 
   case GTK_RESPONSE_ACCEPT:
 
-    gconf_forward_value = (gchar *) gtk_entry_get_text (GTK_ENTRY (entry));
+    gconf_forward_value =
+      (gchar *) gm_entry_dialog_get_text (GM_ENTRY_DIALOG (gw->transfer_call_popup));
     new GMURLHandler (gconf_forward_value, TRUE);
       
     break;
@@ -202,7 +176,8 @@ transfer_call_cb (GtkWidget* widget,
     break;
   }
 
-  gtk_widget_destroy (transfer_call_popup);
+  gtk_widget_destroy (gw->transfer_call_popup);
+  gw->transfer_call_popup = NULL;
 }
 
 
@@ -402,14 +377,16 @@ void about_callback (GtkWidget *widget, gpointer parent_window)
   GdkPixbuf *pixbuf = NULL;
 	
   const gchar *authors [] = {
-      "Damien Sandras <sandras@info.ucl.ac.be>",
+      "Damien Sandras <damien.sandras@it-optics.com>",
       "",
       N_("Code Contributors:"),
       "Kenneth Rohde Christiansen <kenneth@gnu.org>",
+      "Julien Puydt <julien.puydt@club-internet.fr>",
       "Miguel Rodríguez Pérez <migrax@terra.es>",
       "Paul <paul@argo.dyndns.org>", 
       "Roger Hardiman <roger@freebsd.org>",
       "Sébastien Josset <Sebastien.Josset@space.alcatel.fr>",
+      "Stefan Bruëns <lurch@gmx.li>",
       "Tuan <tuan@info.ucl.ac.be>",
       "",
       N_("Artwork:"),
@@ -428,32 +405,22 @@ void about_callback (GtkWidget *widget, gpointer parent_window)
       "Florin Grad <florin@mandrakesoft.com>",
       "Georgi Georgiev <chutz@gg3.net>",
       "Johnny Ström <jonny.strom@netikka.fi>",
-      "Julien Puydt <julien.puydt@club-internet.fr>",
       "Kilian Krause <kk@verfaction.de>",
       "Matthias Marks <matthias@marksweb.de>",
       "Rafael Pinilla <r_pinilla@yahoo.com>",
       "Santiago García Mantiñán <manty@manty.net>",
       "Shawn Pai-Hsiang Hsiao <shawn@eecs.harvard.edu>",
-      "Stefan Bruens <lurch@gmx.li>",
-      "Stéphane Wirtel<stephane.wirtel@belgacom.net>",
+      "Stéphane Wirtel <stephane.wirtel@belgacom.net>",
       "Vincent Deroo <crossdatabase@aol.com>",
       NULL
   };
-
-  const gchar *translators [] = {
-      N_("Internationalisation Maintainer:"),
-      "Christian Rose <menthos@gnu.org>",
-      NULL
-  };
 	
   authors [2] = gettext (authors [2]);
   authors [10] = gettext (authors [10]);
   authors [13] = gettext (authors [13]);
-  translators [0] = gettext (translators [0]);
   
   const char *documenters [] = {
     "Damien Sandras <dsandras@seconix.com>",
-    "Rafael Pinilla <r_pinilla@yahoo.com>",
     NULL
   };
 
@@ -470,7 +437,7 @@ void about_callback (GtkWidget *widget, gpointer parent_window)
 			  "Copyright © 2000, 2003 Damien Sandras",
                           /* Translators: Please test to see if your translation
                            * looks OK and fits within the box */
-			  _("GnomeMeeting is a full-featured H.323\nvideo conferencing application."),
+			  _("GnomeMeeting is full-featured H.323 compatible videoconferencing, VoIP and IP-Telephony application that allows you to make audio and video calls to remote users with H.323 hardware or software."),
 			  (const char **) authors,
                           (const char **) documenters,
                           strcmp (translator_credits, 
@@ -496,17 +463,18 @@ void quit_callback (GtkWidget *widget, gpointer data)
   
   gw = GnomeMeeting::Process ()->GetMainWindow ();
   ep = GnomeMeeting::Process ()->Endpoint ();
-
-  gdk_threads_leave ();
-  ep->ClearAllCalls (H323Connection::EndedByLocalUser, TRUE);
-  gdk_threads_enter ();
   
   gnomemeeting_window_hide (gm);
   gnomemeeting_window_hide (gw->history_window);
   gnomemeeting_window_hide (gw->calls_history_window);
   gnomemeeting_window_hide (gw->ldap_window);
+  gnomemeeting_window_hide (gw->pref_window);
+  
+  gdk_threads_leave ();
+  ep->ClearAllCalls (H323Connection::EndedByLocalUser, TRUE);
+  gdk_threads_enter ();
+
   gtk_widget_hide (gw->docklet);
-  gtk_widget_hide (gw->pref_window);
 
   gtk_main_quit ();
 }  
