@@ -43,6 +43,7 @@
 #include "gatekeeper.h"
 #include "urlhandler.h"
 #include "ils.h"
+#include "lid.h"
 #include "gnomemeeting.h"
 #include "sound_handling.h"
 #include "tray.h"
@@ -93,12 +94,7 @@ GMH323EndPoint::GMH323EndPoint ()
   ils_client = NULL;
   listener = NULL;
 
-  is_transmitting_video = FALSE;
-  is_receiving_video = FALSE;
-  is_transmitting_audio = FALSE;
-  is_receiving_audio = FALSE;
 
-  
   /* Use IPv6 address family by default if available. */
 #ifdef P_HAS_IPV6
   if (PIPSocket::IsIpAddressFamilyV6Supported())
@@ -109,7 +105,6 @@ GMH323EndPoint::GMH323EndPoint ()
   transmitted_video_device = NULL;
   audio_tester = NULL;
   
-  SetNoMediaTimeout (PTimeInterval (0, 15, 0));
   ILSTimer.SetNotifier (PCREATE_NOTIFIER (OnILSTimeout));
   ils_registered = false;
 
@@ -117,6 +112,7 @@ GMH323EndPoint::GMH323EndPoint ()
   GatewayIPTimer.SetNotifier (PCREATE_NOTIFIER (OnGatewayIPTimeout));
   GatewayIPTimer.RunContinuous (PTimeInterval (5));
 
+  NoIncomingMediaTimer.SetNotifier (PCREATE_NOTIFIER (OnNoIncomingMediaTimeout));
   NoAnswerTimer.SetNotifier (PCREATE_NOTIFIER (OnNoAnswerTimeout));
   CallPendingTimer.SetNotifier (PCREATE_NOTIFIER (OnCallPending));
   OutgoingCallTimer.SetNotifier (PCREATE_NOTIFIER (OnOutgoingCall));
@@ -158,16 +154,38 @@ GMH323EndPoint::MakeCallLocked (const PString & call_addr,
   
   con = H323EndPoint::MakeCallLocked (call_addr, call_token);
 
-  if (con)
+#ifdef HAS_IXJ
+  GMLid *lid = NULL;
+  lid = GetLid ();
+#endif
+
+  if (con) {
+    
     OutgoingCallTimer.RunContinuous (PTimeInterval (5));
+
+#ifdef HAS_IXJ
+    if (lid)
+      lid->UpdateState (GMH323EndPoint::Calling); // Calling
+#endif
+  }
   else {
     
     OutgoingCallTimer.Stop ();
 
+#ifdef HAX_IXJ
+    if (lid)
+      lid->UpdateStatus (GMH323EndPoint::Standby); // Busy
+#endif
+
     sound_event_mutex.Wait ();
     GMSoundEvent ("busy_tone_sound");
     sound_event_mutex.Signal ();
   }
+
+#ifdef HAS_IXJ
+  if (lid)
+    lid->Unlock ();
+#endif
   
   return con;
 }
@@ -181,6 +199,9 @@ void GMH323EndPoint::UpdateDevices ()
   GmWindow *gw = NULL;
 
   BOOL preview = FALSE;
+
+  PString dev;
+  gchar *audio_input = NULL;
   
   pw = GnomeMeeting::Process ()->GetPrefWindow ();
   gw = GnomeMeeting::Process ()->GetMainWindow ();
@@ -189,6 +210,7 @@ void GMH323EndPoint::UpdateDevices ()
   /* Get the gconf settings */
   gnomemeeting_threads_enter ();
   preview = gconf_get_bool (VIDEO_DEVICES_KEY "enable_preview");
+  audio_input = gconf_get_string (AUDIO_DEVICES_KEY "input_device");
   gnomemeeting_threads_leave ();
   
   gnomemeeting_sound_daemons_suspend ();
@@ -196,30 +218,40 @@ void GMH323EndPoint::UpdateDevices ()
   /* Do not change these values during calls */
   if (GetCallingState () == GMH323EndPoint::Standby) {
 
-    /* Quicknet hardware */
-    /*    if (PString (player).Find ("/dev/phone") != P_MAX_INDEX
-	|| PString (recorder).Find ("/dev/phone") != P_MAX_INDEX) {
+#ifdef HAS_IXJ
+    GMLid *l = GetLid ();
+    if (l) {
       
-      use_lid = true;
-      }*/
+      use_lid = TRUE;
+      l->Unlock ();
+    }
+    else
+      use_lid = FALSE;
+
+    dev = audio_input;
+    
+    /* Quicknet hardware */
+    if (dev.Find ("phone") != P_MAX_INDEX) {
+          
+      /* Use the quicknet card if needed */
+      if (!use_lid) 
+	CreateLid (audio_input);
+    }
+    else
+      RemoveLid ();
+#endif
+    
 
     /* Video preview */
     if (preview) 
       CreateVideoGrabber (TRUE, TRUE);
     else
       RemoveVideoGrabber ();
-
-    
-#ifdef HAS_IXJ
-    /* Use the quicknet card if needed */
-    if (use_lid) 
-      CreateLid ();
-    else
-      RemoveLid ();
-#endif
   }
 
   gnomemeeting_sound_daemons_resume ();
+
+  g_free (audio_input);
 }
 
 
@@ -251,7 +283,7 @@ GMH323EndPoint::AddAllCapabilities ()
 
 
 void 
-GMH323EndPoint::SetCallingState (unsigned i)
+GMH323EndPoint::SetCallingState (GMH323EndPoint::CallingState i)
 {
   PWaitAndSignal m(cs_access_mutex);
   
@@ -259,7 +291,7 @@ GMH323EndPoint::SetCallingState (unsigned i)
 }
 
 
-unsigned 
+GMH323EndPoint::CallingState
 GMH323EndPoint::GetCallingState (void)
 {
   PWaitAndSignal m(cs_access_mutex);
@@ -316,7 +348,7 @@ GMH323EndPoint::AddUserInputCapabilities ()
 {
   int cap = 0;
 
-  cap = gconf_get_int (GENERAL_KEY "user_input_capability");
+  cap = gconf_get_int (H323_ADVANCED_KEY "dtmf_sending");
     
   if (cap == 3)
     capabilities.SetCapability (0, P_MAX_INDEX, new H323_UserInputCapability(H323_UserInputCapability::SignalToneH245));
@@ -349,16 +381,18 @@ GMH323EndPoint::AddAudioCapabilities ()
   PStringArray to_reorder;
   
   /* Read GConf settings */ 
-  codecs_data = gconf_get_string_list (AUDIO_CODECS_KEY "codecs_list");
-  g711_frames = gconf_get_int (AUDIO_SETTINGS_KEY "g711_frames");
-  gsm_frames = gconf_get_int (AUDIO_SETTINGS_KEY "gsm_frames");
+  codecs_data = gconf_get_string_list (AUDIO_CODECS_KEY "list");
+  g711_frames = gconf_get_int (AUDIO_CODECS_KEY "g711_frames");
+  gsm_frames = gconf_get_int (AUDIO_CODECS_KEY "gsm_frames");
 
-  
 #ifdef HAS_IXJ
   /* Add the audio capabilities provided by the LID Hardware */
   GMLid *l = NULL;
   if ((l = GetLid ())) {
 
+    if (l->IsOpen ())
+      H323_LIDCapability::AddAllCapabilities (*l, capabilities, 0, 0);
+
     /* If the LID can do PCM16 we can use the software
        codecs like GSM too */
     use_pcm16_codecs = l->areSoftwareCodecsSupported ();
@@ -403,21 +437,6 @@ GMH323EndPoint::AddAudioCapabilities ()
 
     SetCapability(0, 0, new H323_LPC10Capability (*this));
   }
-
-  
-#ifdef HAS_IXJ
-  if ((l = GetLid ())) {
-
-    OpalLineInterfaceDevice *lid_device = NULL;
-
-    lid_device = l->GetLidDevice ();
-
-    if (lid_device && lid_device->IsOpen ())
-      H323_LIDCapability::AddAllCapabilities (*lid_device, capabilities, 0, 0);
-
-    l->Unlock ();
-  }
-#endif
   
   
   /* Let's go */
@@ -479,7 +498,7 @@ GMH323EndPoint::TranslateTCPAddress(PIPSocket::Address &local_address,
   gchar *ip = NULL;
 
   gnomemeeting_threads_enter ();
-  ip_translation = gconf_get_bool (NAT_KEY "ip_translation");
+  ip_translation = gconf_get_bool (NAT_KEY "enable_ip_translation");
   gnomemeeting_threads_leave ();
 
   if (ip_translation) {
@@ -596,15 +615,12 @@ GMH323EndPoint::RemoveVideoGrabber ()
 GMVideoGrabber *
 GMH323EndPoint::GetVideoGrabber ()
 {
-  GMVideoGrabber *vg = NULL;
   PWaitAndSignal m(vg_access_mutex);
 
-  vg = video_grabber;
-
-  if (vg)
-    vg->Lock ();
+  if (video_grabber)
+    video_grabber->Lock ();
   
-  return vg;
+  return video_grabber;
 }
 
 
@@ -676,21 +692,23 @@ GMH323EndPoint::OnIncomingCall (H323Connection & connection,
   gchar *forward_host_gconf = NULL;
   IncomingCallMode icm = AVAILABLE;
   BOOL busy_forward = FALSE;
-  BOOL play_sound = FALSE;
   BOOL show_popup = FALSE;
 
   BOOL do_forward = FALSE;
   BOOL do_reject = FALSE;
   BOOL do_answer = FALSE;
+
+#ifdef HAS_IXJ
+  GMLid *l = NULL;
+#endif    
   
   /* Check the gconf keys */
   gnomemeeting_threads_enter ();
   forward_host_gconf = gconf_get_string (CALL_FORWARDING_KEY "forward_host");
-  busy_forward = gconf_get_bool (CALL_FORWARDING_KEY "busy_forward");
+  busy_forward = gconf_get_bool (CALL_FORWARDING_KEY "forward_on_busy");
   icm =
-    (IncomingCallMode) gconf_get_int (CALL_CONTROL_KEY "incoming_call_mode");
-  play_sound = gconf_get_bool (GENERAL_KEY "incoming_call_sound");
-  show_popup = gconf_get_bool (VIEW_KEY "show_popup");
+    (IncomingCallMode) gconf_get_int (CALL_OPTIONS_KEY "incoming_call_mode");
+  show_popup = gconf_get_bool (USER_INTERFACE_KEY "show_popup");
   gnomemeeting_threads_leave ();
 
   if (forward_host_gconf)
@@ -810,13 +828,14 @@ GMH323EndPoint::OnIncomingCall (H323Connection & connection,
   gnomemeeting_main_window_update_sensitivity (GMH323EndPoint::Called);
   gnomemeeting_threads_leave ();
 
-  
-#ifdef HAS_IXJ
-  GMLid *l = NULL;
-    
-  if ((l = GetLid ())) {
 
-    l->RingLine (1);
+  /* Update the LID state */
+#ifdef HAS_IXJ
+  l = GetLid ();
+  
+  if (l) {
+
+    l->UpdateState (GMH323EndPoint::Called);
     l->Unlock ();
   }
 #endif
@@ -900,7 +919,11 @@ GMH323EndPoint::OnConnectionEstablished (H323Connection & connection,
   char *msg = NULL;
   BOOL reg = FALSE;
 
+#ifdef HAS_IXJ
+  GMLid *l = NULL;
+#endif
 
+  
   /* Start refreshing the stats */
   RTPTimer.RunContinuous (PTimeInterval (0, 1));
 
@@ -912,19 +935,8 @@ GMH323EndPoint::OnConnectionEstablished (H323Connection & connection,
   
   /* Get the gconf settings */
   gnomemeeting_threads_enter ();
-  reg = gconf_get_bool (LDAP_KEY "register");
+  reg = gconf_get_bool (LDAP_KEY "enable_registering");
   gnomemeeting_threads_leave ();
-
-
-  /* Remove the progress timeout */
-  if (gw->progress_timeout) {
-
-    gnomemeeting_threads_enter ();
-    gtk_timeout_remove (gw->progress_timeout);
-    gw->progress_timeout = 0;
-    gtk_widget_hide (gw->progressbar);
-    gnomemeeting_threads_leave ();
-  }
   
   
   /* Connected */
@@ -968,11 +980,11 @@ GMH323EndPoint::OnConnectionEstablished (H323Connection & connection,
 
 
 #ifdef HAS_IXJ
-  GMLid *l = NULL;
+  l = GetLid ();
+  
+  if (l) {
 
-  if ((l = GetLid ())) {
-
-    l->RingLine (3);
+    l->UpdateState (GMH323EndPoint::Connected);
     l->Unlock ();
   }
 #endif
@@ -1077,6 +1089,10 @@ GMH323EndPoint::OnConnectionCleared (H323Connection & connection,
 
   GmRtpData *rtp = NULL;
 
+#ifdef HAS_IXJ
+  GMLid *l = NULL;
+#endif
+
   rtp = GnomeMeeting::Process ()->GetRtpData ();
   
   if (connection.GetConnectionStartTime ().IsValid ())
@@ -1085,8 +1101,9 @@ GMH323EndPoint::OnConnectionCleared (H323Connection & connection,
 
   /* Get GConf settings */
   gnomemeeting_threads_enter ();
-  auto_clear_text_chat = gconf_get_bool (GENERAL_KEY "auto_clear_text_chat");
-  reg = gconf_get_bool (LDAP_KEY "register");
+  auto_clear_text_chat =
+    gconf_get_bool (USER_INTERFACE_KEY "auto_clear_text_chat");
+  reg = gconf_get_bool (LDAP_KEY "enable_registering");
   stay_on_top = gconf_get_bool (VIDEO_DISPLAY_KEY "stay_on_top");
   gnomemeeting_threads_leave ();
 
@@ -1171,7 +1188,7 @@ GMH323EndPoint::OnConnectionCleared (H323Connection & connection,
     msg_reason = g_strdup (_("Remote user is unreachable"));
     break;
   case H323Connection::EndedByNoEndPoint :
-    msg_reason = g_strdup (_("Remote user is not running GnomeMeeting"));
+    msg_reason = g_strdup (_("Remote user is unreachable"));
     break;
   case H323Connection::EndedByHostOffline :
     msg_reason = g_strdup (_("Remote host is offline"));
@@ -1225,13 +1242,26 @@ GMH323EndPoint::OnConnectionCleared (H323Connection & connection,
   if (not_current) 
     return;
 
-  
+
   /* Stop the Timers */
   NoAnswerTimer.Stop ();
   CallPendingTimer.Stop (); 
   OutgoingCallTimer.Stop ();
-
+  NoIncomingMediaTimer.Stop ();
   
+  
+  if (gw->incoming_call_popup) {
+
+    gtk_widget_destroy (gw->incoming_call_popup);
+    gw->incoming_call_popup = NULL;
+  }
+
+  if (gw->transfer_call_popup) 
+    gtk_dialog_response (GTK_DIALOG (gw->transfer_call_popup),
+			 GTK_RESPONSE_REJECT);
+  gnomemeeting_threads_leave ();
+  
+
   /* Play busy tone */
   sound_event_mutex.Wait ();
   GMSoundEvent ("busy_tone_sound");
@@ -1240,33 +1270,15 @@ GMH323EndPoint::OnConnectionCleared (H323Connection & connection,
   
   gnomemeeting_threads_enter ();
   gtk_label_set_text (GTK_LABEL (gw->remote_name), "");
-  gnomemeeting_main_window_enable_statusbar_progress (false);
-
-  if (gw->incoming_call_popup) {
-
-    gtk_widget_destroy (gw->incoming_call_popup);
-    gw->incoming_call_popup = NULL;
-  }
   gnomemeeting_threads_leave ();
   
-  
-  /* No need to do all that if we are simply receiving an incoming call
-     that was rejected because of DND */
-  if (GetCallingState () != GMH323EndPoint::Called
-      && GetCallingState () != GMH323EndPoint::Calling) {
-
-    /* Update ILS if needed */
-    if (reg)
-      ILSRegister ();
-  }
-
-
   /* Play Busy Tone */
 #ifdef HAS_IXJ
-  GMLid *l = NULL;
-  if ((l = GetLid ())) {
+  l = GetLid ();
+  
+  if (l) {
 
-    l->RingLine (2);
+    l->UpdateState (GMH323EndPoint::Standby);
     l->Unlock ();
   }
 #endif
@@ -1297,12 +1309,10 @@ GMH323EndPoint::OnConnectionCleared (H323Connection & connection,
   }
 
 
-  is_transmitting_video = FALSE;
-  is_receiving_video = FALSE;
-  is_transmitting_audio = FALSE;
-  is_receiving_audio = FALSE;
-
+  gw->audio_reception_popup = NULL;
+  gw->audio_transmission_popup = NULL;
 
+  
   /* No Audio reception or transmission */
   gnomemeeting_menu_update_sensitivity (GMH323EndPoint::Standby);
   gnomemeeting_main_window_update_sensitivity (GMH323EndPoint::Standby);
@@ -1316,6 +1326,17 @@ GMH323EndPoint::OnConnectionCleared (H323Connection & connection,
   SetCallingState (GMH323EndPoint::Standby);
 
 
+  /* No need to do all that if we are simply receiving an incoming call
+     that was rejected because of DND */
+  if (GetCallingState () != GMH323EndPoint::Called
+      && GetCallingState () != GMH323EndPoint::Calling) {
+
+    /* Update ILS if needed */
+    if (reg)
+      ILSRegister ();
+  }
+
+
   /* Try to update the devices use if some settings were changed 
      during the call */
   UpdateDevices ();
@@ -1367,9 +1388,9 @@ GMH323EndPoint::SetUserNameAndAlias ()
   gnomemeeting_threads_enter ();
   firstname = gconf_get_string (PERSONAL_DATA_KEY "firstname");
   lastname = gconf_get_string (PERSONAL_DATA_KEY "lastname");
-  alias = gconf_get_string (GATEKEEPER_KEY "gk_alias");  
+  alias = gconf_get_string (H323_GATEKEEPER_KEY "alias");  
   gk_alias_as_first =
-    gconf_get_bool (GATEKEEPER_KEY "register_alias_as_primary");  
+    gconf_get_bool (H323_GATEKEEPER_KEY "register_alias_as_primary");  
   gnomemeeting_threads_leave ();
 
   
@@ -1461,36 +1482,32 @@ GMH323EndPoint::Init ()
 {
   /* Update the internal state */
   autoStartTransmitVideo =
-    gconf_get_bool (VIDEO_SETTINGS_KEY "enable_video_transmission");
+    gconf_get_bool (VIDEO_CODECS_KEY "enable_video_transmission");
   autoStartReceiveVideo =
-    gconf_get_bool (VIDEO_SETTINGS_KEY "enable_video_reception");
-
-  disableH245Tunneling = !gconf_get_bool (GENERAL_KEY "h245_tunneling");
-  disableFastStart = !gconf_get_bool (GENERAL_KEY "fast_start");
-
-
-  /* Add capabilities */
-  AddAllCapabilities ();
+    gconf_get_bool (VIDEO_CODECS_KEY "enable_video_reception");
 
+  disableH245Tunneling = !gconf_get_bool (H323_ADVANCED_KEY "enable_h245_tunneling");
+  disableFastStart = !gconf_get_bool (H323_ADVANCED_KEY "enable_fast_start");
+  disableH245inSetup = !gconf_get_bool (H323_ADVANCED_KEY "enable_early_h245");
 
   /* Setup ports */
   SetPorts ();
-
   
   /* Update general devices configuration */
   UpdateDevices ();
-
   
   /* Set the User Name and Alias */  
   SetUserNameAndAlias ();
 
+  /* Add capabilities */
+  AddAllCapabilities ();
 
   /* Register to gatekeeper */
-  if (gconf_get_int (GATEKEEPER_KEY "registering_method"))
+  if (gconf_get_int (H323_GATEKEEPER_KEY "registering_method"))
     GatekeeperRegister ();
 
   /* The LDAP part, if needed */
-  if (gconf_get_bool (LDAP_KEY "register"))
+  if (gconf_get_bool (LDAP_KEY "enable_registering"))
     ILSRegister ();
   
   
@@ -1499,6 +1516,15 @@ GMH323EndPoint::Init ()
 }
 
 
+void
+GMH323EndPoint::OnNoIncomingMediaTimeout (PTimer &,
+					  INT)
+{
+  if (gconf_get_bool (CALL_OPTIONS_KEY "clear_inactive_calls"))
+    ClearAllCalls (H323Connection::EndedByTransportFail, FALSE);
+}
+
+
 void 
 GMH323EndPoint::OnILSTimeout (PTimer &,
 			      INT)
@@ -1508,7 +1534,7 @@ GMH323EndPoint::OnILSTimeout (PTimer &,
   gboolean reg = false;
 
   gnomemeeting_threads_enter ();
-  reg = gconf_get_bool (LDAP_KEY "register");
+  reg = gconf_get_bool (LDAP_KEY "enable_registering");
   gnomemeeting_threads_leave ();
 
 
@@ -1559,7 +1585,7 @@ GMH323EndPoint::OpenAudioChannel (H323Connection & connection,
 				  H323AudioCodec & codec)
 {
   PSoundChannel *sound_channel = NULL;
-
+  
   PString plugin;
   PString device;
   
@@ -1571,11 +1597,7 @@ GMH323EndPoint::OpenAudioChannel (H323Connection & connection,
   
   gchar *msg = NULL;
 
-  if ((is_encoding && is_transmitting_audio)
-      || (!is_encoding && is_receiving_audio))
-    return FALSE;
-
-  
+      
   /* Wait that the primary call has terminated (in case of transfer)
      before opening the channels for the second call */
   TransferCallWait ();
@@ -1588,31 +1610,27 @@ GMH323EndPoint::OpenAudioChannel (H323Connection & connection,
   
   
   gnomemeeting_threads_enter ();
-  sd = gconf_get_bool (AUDIO_SETTINGS_KEY "sd");
+  sd = gconf_get_bool (AUDIO_CODECS_KEY "enable_silence_detection");
   gnomemeeting_threads_leave ();
 
-  if (is_encoding)
+  if (is_encoding) 
     codec.SetSilenceDetectionMode (!sd ?
 				   H323AudioCodec::NoSilenceDetection :
 				   H323AudioCodec::AdaptiveSilenceDetection);
-
+  
 
   /* Suspend the daemons */
   gnomemeeting_sound_daemons_suspend ();
 
 #ifdef HAS_IXJ
   GMLid *l = NULL;
-  OpalLineInterfaceDevice *lid_device = NULL;
-
-  if ((l = GetLid ())) 
-    lid_device = l->GetLidDevice ();
 
   /* If we are using a hardware LID, connect the audio stream to the LID */
-  if (lid_device && lid_device->IsOpen()) {
+  if ((l = GetLid ()) && l->IsOpen()) {
 
-    l->RingLine (4);
+    lid->StopTone (0);
     
-    if (!codec.AttachChannel (new OpalLineChannel (*lid_device,
+    if (!codec.AttachChannel (new OpalLineChannel (*l,
 						   OpalIxJDevice::POTSLine,
 						   codec))) {
 
@@ -1632,74 +1650,80 @@ GMH323EndPoint::OpenAudioChannel (H323Connection & connection,
   }
   else
 #endif
-   {   
-     gnomemeeting_threads_enter ();
-     plugin = gconf_get_string (AUDIO_DEVICES_KEY "plugin");
-     if (is_encoding)
-       device = gconf_get_string (AUDIO_DEVICES_KEY "input_device");
-     else
-       device = gconf_get_string (AUDIO_DEVICES_KEY "output_device");
-     gnomemeeting_threads_leave ();
+    {   
+      gnomemeeting_threads_enter ();
+      plugin = gconf_get_string (AUDIO_DEVICES_KEY "plugin");
+      if (is_encoding)
+	device = gconf_get_string (AUDIO_DEVICES_KEY "input_device");
+      else
+	device = gconf_get_string (AUDIO_DEVICES_KEY "output_device");
+      gnomemeeting_threads_leave ();
 
-     if (device.Find (_("No device found")) == P_MAX_INDEX) {
+      if (device.Find (_("No device found")) == P_MAX_INDEX) {
+
+	sound_event_mutex.Wait ();
+	sound_channel = 
+	  PSoundChannel::CreateOpenedChannel (plugin,
+					      device,
+					      is_encoding ?
+					      PSoundChannel::Recorder
+					      : PSoundChannel::Player, 
+					      1, 8000, 16);
+	sound_event_mutex.Signal ();
 
-       sound_event_mutex.Wait ();
-       sound_channel = 
-	 PSoundChannel::CreateOpenedChannel (plugin,
-					     device,
-					     is_encoding ?
-					     PSoundChannel::Recorder
-					     : PSoundChannel::Player, 
-					     1, 8000, 16); 
-       sound_event_mutex.Signal ();
        
-       if (sound_channel) {
+	if (sound_channel) {
 
-	 /* Translators : the full sentence is "Opening %s for playing with
-	    plugin %s" or "Opening %s for recording with plugin" */
-	 msg = g_strdup_printf (_("Opened %s for %s with plugin %s"),
-				(const char *) device,
-				is_encoding ? _("recording") : _("playing"),
-				(const char *) plugin);
+	  /* Translators : the full sentence is "Opening %s for playing with
+	     plugin %s" or "Opening %s for recording with plugin" */
+	  msg = g_strdup_printf (_("Opened %s for %s with plugin %s"),
+				 (const char *) device,
+				 is_encoding ? _("recording") : _("playing"),
+				 (const char *) plugin);
 
-	 gnomemeeting_threads_enter ();
-	 gnomemeeting_log_insert (gw->history_text_view, msg);
-	 gnomemeeting_threads_leave ();
-	 g_free (msg);
+	  gnomemeeting_threads_enter ();
+	  gnomemeeting_log_insert (gw->history_text_view, msg);
+	  gnomemeeting_threads_leave ();
+	  g_free (msg);
 
-	 /* Control the channel and attach it to the codec */
-	 sound_channel->SetBuffers (bufferSize, soundChannelBuffers);
-	 no_error = codec.AttachChannel (sound_channel);
-       }
-       else
-	 no_error = FALSE; /* No PSoundChannel */
-     }
-     else
-       return FALSE; /* Device was _("No device found"), ignore, no popup */
-   }
+	  /* Control the channel and attach it to the codec, do not
+	     auto delete it */
+	  sound_channel->SetBuffers (bufferSize, soundChannelBuffers);
+	  no_error = codec.AttachChannel (sound_channel);
+
+	  /* Update the volume sliders */
+	  gnomemeeting_threads_enter ();
+	  GetDeviceVolume (vol_play, vol_rec);
+	  GTK_ADJUSTMENT (gw->adj_play)->value = vol_play;
+	  GTK_ADJUSTMENT (gw->adj_rec)->value = vol_rec;
+	  gtk_widget_queue_draw (GTK_WIDGET (gw->audio_settings_frame));
+	  gnomemeeting_threads_leave ();
+	}
+	else
+	  no_error = FALSE; /* No PSoundChannel */
+      }
+      else
+	return FALSE; /* Device was _("No device found"), ignore, no popup */
+    }
 
   
-  gnomemeeting_threads_enter ();
-  
-  /* Update the volume sliders */
-  GetDeviceVolume (vol_play, vol_rec);
-  GTK_ADJUSTMENT (gw->adj_play)->value = vol_play;
-  GTK_ADJUSTMENT (gw->adj_rec)->value = vol_rec;
-  gtk_widget_queue_draw (GTK_WIDGET (gw->audio_settings_frame));
-  gnomemeeting_threads_leave ();
-
   if (!no_error) {
 
     gnomemeeting_threads_enter ();
 
-    if (is_encoding)
-      gnomemeeting_error_dialog (GTK_WINDOW (gm), _("Could not open audio channel for audio transmission"), _("An error occured while trying to record from the soundcard for the audio transmission. Please check that your soundcard is not busy and that your driver supports full-duplex.\nThe audio transmission has been disabled."));
+    if (is_encoding) {
+
+      if (!gw->audio_transmission_popup)
+	gw->audio_transmission_popup =
+	  gnomemeeting_error_dialog (GTK_WINDOW (gm), _("Could not open audio channel for audio transmission"), _("An error occured while trying to record from the soundcard for the audio transmission. Please check that your soundcard is not busy and that your driver supports full-duplex.\nThe audio transmission has been disabled."));
+    }
     else
-      gnomemeeting_error_dialog (GTK_WINDOW (gm), _("Could not open audio channel for audio reception"), _("An error occured while trying to play audio to the soundcard for the audio reception. Please check that your soundcard is not busy and that your driver supports full-duplex.\nThe audio reception has been disabled."));
+      if (!gw->audio_reception_popup)
+	gw->audio_reception_popup =
+	  gnomemeeting_error_dialog (GTK_WINDOW (gm), _("Could not open audio channel for audio reception"), _("An error occured while trying to play audio to the soundcard for the audio reception. Please check that your soundcard is not busy and that your driver supports full-duplex.\nThe audio reception has been disabled."));
     gnomemeeting_threads_leave ();
   }
-  else
-    is_encoding ? is_transmitting_audio = TRUE : is_receiving_audio = TRUE;
+
     
   return no_error;
 }
@@ -1911,6 +1935,19 @@ GMH323EndPoint::OnRTPTimeout (PTimer &, INT)
     if (rtp->re_video_pos >= 50) rtp->re_video_pos = 0;
   }
 
+
+  /* If we didn't receive any audio and video data this time,
+     then we start the timer */
+  if (rtp->re_video_speed [rtp->re_video_pos -1] == 0
+      && rtp->re_audio_speed [rtp->re_audio_pos -1] == 0) {
+    
+    if (!NoIncomingMediaTimer.IsRunning ()) 
+      NoIncomingMediaTimer.SetInterval (0, 30);
+  }
+  else
+    NoIncomingMediaTimer.Stop ();
+  
+
   msg = g_strdup_printf 
     (_("%.2ld:%.2ld:%.2ld  A:%.2f/%.2f   V:%.2f/%.2f"), 
      (long) t.GetHours (), (long) (t.GetMinutes () % 60), 
@@ -1958,7 +1995,7 @@ GMH323EndPoint::OnRTPTimeout (PTimer &, INT)
   gtk_label_set_text (GTK_LABEL (gw->stats_label), stats_msg);
   g_free (stats_msg);
 
-  if (gconf_get_int (VIEW_KEY "control_panel_section") == 0)
+  if (gconf_get_int (USER_INTERFACE_KEY "main_window/control_panel_section") == 0)
     gtk_widget_queue_draw_area (gw->stats_drawing_area, 0, 0, GTK_WIDGET (gw->stats_drawing_area)->allocation.width, GTK_WIDGET (gw->stats_drawing_area)->allocation.height);
   gdk_threads_leave ();
 
@@ -1994,7 +2031,7 @@ GMH323EndPoint::OnGatewayIPTimeout (PTimer &,
   gboolean ip_checking = false;
 
   gdk_threads_enter ();
-  ip_checking = gconf_get_bool (NAT_KEY "ip_checking");
+  ip_checking = gconf_get_bool (NAT_KEY "enable_ip_checking");
   gdk_threads_leave ();
 
   if (ip_checking) {
@@ -2021,7 +2058,7 @@ GMH323EndPoint::OnGatewayIPTimeout (PTimer &,
     }
   }
 
-  GatewayIPTimer.RunContinuous (PTimeInterval (0, 15));
+  GatewayIPTimer.RunContinuous (PTimeInterval (0, 0, 15));
 }
 
 
@@ -2045,7 +2082,7 @@ GMH323EndPoint::OnNoAnswerTimeout (PTimer &,
   
   /* Forwarding on no answer */
   no_answer_forward = 
-    gconf_get_bool (CALL_FORWARDING_KEY "no_answer_forward");
+    gconf_get_bool (CALL_FORWARDING_KEY "forward_on_no_answer");
   forward_host_gconf = 
     gconf_get_string (CALL_FORWARDING_KEY "forward_host");
 
@@ -2146,6 +2183,11 @@ GMH323EndPoint::DeviceVolume (BOOL set,
   H323Codec *raw_codec = NULL;
   H323Connection *con = NULL;
 
+#ifdef HAS_IXJ
+  GMLid *l = NULL;
+  BOOL has_lid = FALSE;
+#endif
+
   BOOL err = TRUE;
   PString call_token;
 
@@ -2155,30 +2197,48 @@ GMH323EndPoint::DeviceVolume (BOOL set,
 
   if (con) {
 
-    for (int cpt = 0 ; cpt < 2 ; cpt ++) {
+#ifdef HAS_IXJ
+    if (set) {
+      
+      l = GetLid ();
+      if (l) {
 
-      /* TRUE = from_remote = playing */
-      channel = 
-	con->FindChannel (RTP_Session::DefaultAudioSessionID, (cpt == 0));
+	l->SetVolume (play_vol, rec_vol);
+	l->Unlock ();
+	has_lid = TRUE;
+      }
+    }
+#endif
 
-      if (channel) {
+    if (!has_lid) {
 
-	raw_codec = channel->GetCodec();
+      for (int cpt = 0 ; cpt < 2 ; cpt ++) {
 
-	if (raw_codec) {
+	/* TRUE = from_remote = playing */
+	channel = 
+	  con->FindChannel (RTP_Session::DefaultAudioSessionID, (cpt == 0));
 
-	  sound_channel = (PSoundChannel *) raw_codec->GetRawDataChannel ();
-	  if (sound_channel)
-	    if (set) {
+	if (channel) {
+
+	  raw_codec = channel->GetCodec();
+
+	  if (raw_codec) {
+
+	    sound_channel = (PSoundChannel *) raw_codec->GetRawDataChannel ();
+	    if (sound_channel)
+	      if (set) {
 	      
-	      err = 
-		sound_channel->SetVolume ((cpt == 0)?play_vol:rec_vol) && err;
-	    }
-	    else {
+		err = 
+		  sound_channel->SetVolume ((cpt == 0)?play_vol:rec_vol)
+		  && err;
+	      }
+	      else {
 
-	      err = 
-		sound_channel->GetVolume ((cpt == 0)?play_vol:rec_vol) && err;
-	    }
+		err = 
+		  sound_channel->GetVolume ((cpt == 0)?play_vol:rec_vol)
+		  && err;
+	      }
+	  }
 	}
       }
     }
@@ -2205,11 +2265,7 @@ GMH323EndPoint::OpenVideoChannel (H323Connection & connection,
 
   BOOL result = FALSE;
 
-  if ((is_encoding && is_transmitting_video)
-      || (!is_encoding && is_receiving_video))
-    return FALSE;
   
-
   /* Wait that the primary call has terminated (in case of transfer)
      before opening the channels for the second call */
   TransferCallWait ();
@@ -2224,10 +2280,10 @@ GMH323EndPoint::OpenVideoChannel (H323Connection & connection,
   if (is_encoding && autoStartTransmitVideo) {
 
     gnomemeeting_threads_enter ();
-    vq = gconf_get_int (VIDEO_SETTINGS_KEY "tr_vq");
-    bf = gconf_get_int (VIDEO_SETTINGS_KEY "tr_ub");
-    bitrate = gconf_get_int (VIDEO_SETTINGS_KEY "maximum_video_bandwidth");
-    tr_fps = gconf_get_int (VIDEO_SETTINGS_KEY "tr_fps");
+    vq = gconf_get_int (VIDEO_CODECS_KEY "transmitted_video_quality");
+    bf = gconf_get_int (VIDEO_CODECS_KEY "transmitted_background_blocks");
+    bitrate = gconf_get_int (VIDEO_CODECS_KEY "maximum_video_bandwidth");
+    tr_fps = gconf_get_int (VIDEO_CODECS_KEY "transmitted_fps");
     gnomemeeting_threads_leave ();
 
 
@@ -2271,9 +2327,6 @@ GMH323EndPoint::OpenVideoChannel (H323Connection & connection,
 
     if (channel)
       result = codec.AttachChannel (channel, FALSE);
-
-    if (result)
-      is_transmitting_video = TRUE;
     
     return result;
   }
@@ -2300,9 +2353,6 @@ GMH323EndPoint::OpenVideoChannel (H323Connection & connection,
     if (channel)
       result = codec.AttachChannel (channel);
 
-    if (result)
-      is_receiving_video = TRUE;
-	  
     return result;
   }
 
@@ -2315,39 +2365,38 @@ GMH323EndPoint::OpenVideoChannel (H323Connection & connection,
 GMLid *
 GMH323EndPoint::GetLid (void)
 {
-  GMLid *l = NULL;
-
-  lid_access_mutex.Wait ();
-  l = lid;
+  PWaitAndSignal m(lid_access_mutex);
+    
   if (lid) 
     lid->Lock ();
 
-  lid_access_mutex.Signal ();
-
-  return l;
+  return lid;
 }
 
 
-void
-GMH323EndPoint::CreateLid (void)
+GMLid *
+GMH323EndPoint::CreateLid (PString lid_device)
 {
-  lid_access_mutex.Wait ();
-  if (!lid)
-    lid = new GMLid ();
-  lid_access_mutex.Signal ();
+  PWaitAndSignal m(lid_access_mutex);
+  
+  if (lid)
+    delete (lid);
+
+  lid = new GMLid (lid_device);
+
+  return lid;
 }
 
 
 void
 GMH323EndPoint::RemoveLid (void)
 {
-  lid_access_mutex.Wait ();
-  if (lid) {
-    
+  PWaitAndSignal m(lid_access_mutex);
+  
+  if (lid)     
     delete (lid);
-    lid = NULL;
-  }
-  lid_access_mutex.Signal ();
+
+  lid = NULL;
 }
 #endif
 
