@@ -1,6 +1,6 @@
- 
+
 /* GnomeMeeting -- A Video-Conferencing application
- * Copyright (C) 2000-2002 Damien Sandras
+ * Copyright (C) 2000-2003 Damien Sandras
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,74 +15,60 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ *
+ * GnomeMeting is licensed under the GPL license and as a special exception,
+ * you have permission to link or otherwise combine this program with the
+ * programs OpenH323 and Pwlib, and distribute the combination, without
+ * applying the requirements of the GNU GPL to the OpenH323 program, as long
+ * as you do follow the requirements of the GNU GPL for all the rest of the
+ * software thus combined.
  */
 
+
 /*
  *                         gdkvideoio.cpp  -  description
  *                         ------------------------------
  *   begin                : Sat Feb 17 2001
- *   copyright            : (C) 2000-2002 by Damien Sandras
- *   description          : Class to permit to display in GDK Drawing Area
- *   email                : dsandras@seconix.com
+ *   copyright            : (C) 2000-2003 by Damien Sandras
+ *   description          : Class to permit to display in GDK Drawing Area or
+ *                          SDL.
  *
  */
 
+
 #include "../config.h"
 
+#include "gdkvideoio.h"
+#include "gnomemeeting.h"
+#include "misc.h"
+#include "menu.h"
+
+#include <ptlib/vconvert.h>
 
 #ifdef HAS_SDL
 #include <SDL.h>
 #endif
 
-#include <sys/time.h>
-
-
-#include "gdkvideoio.h"
-#include "common.h"
-#include "gnomemeeting.h"
-#include "misc.h"
-#include "menu.h"
-
 #define new PNEW
 
-
 /* Global Variables */
 
 extern GtkWidget *gm;
-extern GnomeMeeting *MyApp;
-
 
+int GDKVideoOutputDevice::devices_nbr = 0;
 
 
 /* The Methods */
-
-GDKVideoOutputDevice::GDKVideoOutputDevice(GmWindow *w)
-{
-  transmitted_frame_number = 0;
-  received_frame_number = 0;
-
-  gw = w;
-
-  /* Used to distinguish between input and output device. */
-  device_id = REMOTE; 
-
-#ifdef HAS_SDL
-  screen = NULL;
-  overlay = NULL;
-#endif
-}
-
-
 GDKVideoOutputDevice::GDKVideoOutputDevice(int idno, GmWindow *w)
 {
-  transmitted_frame_number = 0;
-  received_frame_number = 0;
-
   gw = w;
 
   /* Used to distinguish between input and output device. */
   device_id = idno; 
 
+  devices_nbr++;
+  
 #ifdef HAS_SDL
   screen = NULL;
   overlay = NULL;
@@ -108,18 +94,20 @@ GDKVideoOutputDevice::~GDKVideoOutputDevice()
   }
 #endif
 
+  devices_nbr--;
+  
   /* Hide the 2 popup windows */
   gnomemeeting_threads_enter ();
-
-  gtk_widget_hide_all (GTK_WIDGET (gw->local_video_window));
-  gtk_widget_hide_all (GTK_WIDGET (gw->remote_video_window));
+  gnomemeeting_window_hide (GTK_WIDGET (gw->local_video_window));
+  gnomemeeting_window_hide (GTK_WIDGET (gw->remote_video_window));
   gnomemeeting_threads_leave ();
 }
 
 
-BOOL GDKVideoOutputDevice::Redraw (const void * frame)
+BOOL GDKVideoOutputDevice::Redraw ()
 {
   GtkWidget *image = NULL;
+  GtkWidget *window = NULL;
   GdkPixbuf *src_pic = NULL;
   GdkPixbuf *zoomed_pic = NULL;
   GdkPixbuf *tmp = NULL;
@@ -129,13 +117,12 @@ BOOL GDKVideoOutputDevice::Redraw (const void * frame)
 
   gboolean unref = true;
 
-  enum GdkInterpType interp_type = GDK_INTERP_NEAREST;
+  GdkInterpType interp_type = GDK_INTERP_NEAREST;
   int zoomed_width = GM_QCIF_WIDTH; 
   int zoomed_height = GM_QCIF_HEIGHT;
 
   int display = 0;
 
-
   /* Common to the 2 instances of gdkvideoio */
   static GdkPixbuf *local_pic = NULL;
   static gboolean logo_displayed = false;
@@ -146,8 +133,10 @@ BOOL GDKVideoOutputDevice::Redraw (const void * frame)
   static gboolean has_to_fs = false;
   static gboolean has_to_switch_fs = false;
   static gboolean old_fullscreen = false;
-
   static int fs_device = 0;
+  Uint32 rmask, gmask, bmask, amask;
+  SDL_Surface *surface = NULL;
+  SDL_Surface *blit_conf = NULL;
 #endif
 
 
@@ -161,7 +150,7 @@ BOOL GDKVideoOutputDevice::Redraw (const void * frame)
   /* Updates the zoom value */
   zoom = 
     gconf_client_get_float (client, 
-			    "/apps/gnomemeeting/video_display/zoom_factor", 
+			    VIDEO_DISPLAY_KEY "zoom_factor", 
 			    NULL);
   if (zoom != 0.5 && zoom != 1 && zoom != 2)
     zoom = 1.0;
@@ -169,7 +158,7 @@ BOOL GDKVideoOutputDevice::Redraw (const void * frame)
 #ifdef HAS_SDL 
   fullscreen =
     gconf_client_get_bool (client, 
-			  "/apps/gnomemeeting/video_display/fullscreen", 0);
+			  VIDEO_DISPLAY_KEY "start_in_fullscreen", 0);
 #endif
 
 
@@ -177,7 +166,7 @@ BOOL GDKVideoOutputDevice::Redraw (const void * frame)
   
   /* What do we display: what gconf tells us except if we are not in 
      a call, or if it is not a valid choice */
-  if (MyApp->Endpoint ()->GetCallingState () != 2) {
+  if (GnomeMeeting::Process ()->Endpoint ()->GetCallingState () != 2) {
 
     display = 0;
   }
@@ -185,17 +174,18 @@ BOOL GDKVideoOutputDevice::Redraw (const void * frame)
 
     display = 
       gconf_client_get_int (client, 
-			    "/apps/gnomemeeting/video_display/video_view", 
+			    VIDEO_DISPLAY_KEY "video_view", 
 			    NULL);
 
-    if (MyApp->Endpoint ()->GetVideoChannelsNumber () <= 1)
+    if (devices_nbr <= 1)
       if (device_id == REMOTE)
 	display = REMOTE_VIDEO;
       else if (device_id == LOCAL)
 	display = LOCAL_VIDEO;
   }
 
-  gnomemeeting_video_submenu_select (display);
+  gtk_radio_menu_select_with_id (gw->main_menu, "local_video", display);
+  gtk_radio_menu_select_with_id (gw->video_popup_menu, "local_video", display);
 
   /* Show or hide the different windows if needed */
   if (display == BOTH) { /* display == BOTH */
@@ -208,27 +198,25 @@ BOOL GDKVideoOutputDevice::Redraw (const void * frame)
     }
 
     if (!GTK_WIDGET_VISIBLE (gw->local_video_window))
-      gtk_widget_show_all (GTK_WIDGET (gw->local_video_window));
+      gnomemeeting_window_show (GTK_WIDGET (gw->local_video_window));
     
     if (!GTK_WIDGET_VISIBLE (gw->remote_video_window))
-      gtk_widget_show_all (GTK_WIDGET (gw->remote_video_window));
+      gnomemeeting_window_show (GTK_WIDGET (gw->remote_video_window));
 
     if (device_id == REMOTE) {
 
-      gtk_window_get_size (GTK_WINDOW (gw->remote_video_window), 
-			   &zoomed_width, &zoomed_height);
-      zoomed_width = zoomed_width - GM_FRAME_SIZE;
-      zoomed_height = zoomed_height - GM_FRAME_SIZE;
       image = gw->remote_video_image;
+      window = gw->remote_video_window;
     }
     else {
 
-      gtk_window_get_size (GTK_WINDOW (gw->local_video_window), 
-			   &zoomed_width, &zoomed_height);
-      zoomed_width = zoomed_width - GM_FRAME_SIZE;
-      zoomed_height = zoomed_height - GM_FRAME_SIZE;
       image = gw->local_video_image;
-    } 
+      window = gw->local_video_window;
+    }
+
+    gtk_window_get_size (GTK_WINDOW (window), 
+			 &zoomed_width,
+			 &zoomed_height);
   }
   else {
 
@@ -245,27 +233,24 @@ BOOL GDKVideoOutputDevice::Redraw (const void * frame)
 	 the data for the LOCAL window */
       if (device_id == LOCAL) {
 
-	image = gw->local_video_image;
-
 	gtk_window_get_size (GTK_WINDOW (gw->local_video_window), 
-			     &zoomed_width, &zoomed_height);
-	zoomed_width = zoomed_width - GM_FRAME_SIZE;
-	zoomed_height = zoomed_height - GM_FRAME_SIZE;
+			     &zoomed_width,
+			     &zoomed_height);
       }
 
       if (!GTK_WIDGET_VISIBLE (gw->local_video_window))
-	gtk_widget_show_all (GTK_WIDGET (gw->local_video_window));
+	gnomemeeting_window_show (GTK_WIDGET (gw->local_video_window));
       
       if (GTK_WIDGET_VISIBLE (gw->remote_video_window))
-	gtk_widget_hide_all (GTK_WIDGET (gw->remote_video_window));
+	gnomemeeting_window_hide (GTK_WIDGET (gw->remote_video_window));
     }
     else { /* display != BOTH && display != BOTH_LOCAL */
       
       if (GTK_WIDGET_VISIBLE (gw->local_video_window))
-	gtk_widget_hide_all (GTK_WIDGET (gw->local_video_window));
+	gnomemeeting_window_hide (GTK_WIDGET (gw->local_video_window));
       
       if (GTK_WIDGET_VISIBLE (gw->remote_video_window))
-	gtk_widget_hide_all (GTK_WIDGET (gw->remote_video_window));
+	gnomemeeting_window_hide (GTK_WIDGET (gw->remote_video_window));
     }
   }
 
@@ -279,10 +264,8 @@ BOOL GDKVideoOutputDevice::Redraw (const void * frame)
   if ((screen) && (!fullscreen)) {
     
     SDL_FreeSurface (screen);
-    if (overlay)
-      SDL_FreeYUVOverlay (overlay);
     screen = NULL;
-    overlay = NULL;
+    
     SDL_Quit ();
   }
   else
@@ -299,33 +282,26 @@ BOOL GDKVideoOutputDevice::Redraw (const void * frame)
       
     zoomed_width = 
       gconf_client_get_int (client, 
-			    "/apps/gnomemeeting/video_display/fullscreen_width", 
+			    VIDEO_DISPLAY_KEY "fullscreen_width", 
 			    NULL);
     zoomed_height = 
       gconf_client_get_int (client, 
-			    "/apps/gnomemeeting/video_display/fullscreen_height", 
+			    VIDEO_DISPLAY_KEY "fullscreen_height", 
 			    NULL);
     }
 #endif
 
   
-  if ((int) (buffer.GetSize ()) != (int) (frameWidth * frameHeight * 3))
-    buffer.SetSize(frameWidth * frameHeight * 3);
-
-  if (frame)
-    H323VideoDevice::Redraw(frame);
-
-
   /* The real size picture */
   tmp =  
-    gdk_pixbuf_new_from_data ((const guchar *) buffer,
+    gdk_pixbuf_new_from_data ((const guchar *) frameStore,
 			      GDK_COLORSPACE_RGB, FALSE, 8, frameWidth,
 			      frameHeight, frameWidth * 3, NULL, NULL);
   src_pic = gdk_pixbuf_copy (tmp);
   g_object_unref (tmp);
 
 
-  if (gconf_client_get_bool (client, "/apps/gnomemeeting/video_display/bilinear_filtering", NULL)) 
+  if (gconf_client_get_bool (client, VIDEO_DISPLAY_KEY "enable_bilinear_filtering", NULL)) 
     interp_type = GDK_INTERP_BILINEAR;
 
 
@@ -391,8 +367,6 @@ BOOL GDKVideoOutputDevice::Redraw (const void * frame)
 	  has_to_fs = !has_to_fs;
 	  fullscreen = has_to_fs;
 	  has_to_switch_fs = true;
-	  gconf_client_set_bool (client, 
-				 "/apps/gnomemeeting/video_display/fullscreen", fullscreen, 0);
 	}
       }
 
@@ -443,13 +417,11 @@ BOOL GDKVideoOutputDevice::Redraw (const void * frame)
   /* Display local in a SDL window, or the selected device in fullscreen */
   if ( (has_to_fs) && (device_id == fs_device) ) {
   
-    unsigned char *base;
-
     gnomemeeting_threads_enter ();
     sdl_mutex.Wait ();
    
     /* Go fullscreen */
-    if (has_to_switch_fs) {
+    if (has_to_switch_fs || (has_to_fs && !screen)) {
       
 	screen = SDL_SetVideoMode (640, 480, 0, 
 				   SDL_SWSURFACE | SDL_HWSURFACE | 
@@ -460,29 +432,39 @@ BOOL GDKVideoOutputDevice::Redraw (const void * frame)
       has_to_switch_fs = false;
     }
 
-    base = (unsigned char *) frame;
-    
 
-    if (overlay)
-      SDL_FreeYUVOverlay (overlay);
-    overlay = SDL_CreateYUVOverlay (frameWidth, frameHeight, 
-				    SDL_IYUV_OVERLAY, screen);
-    
-    SDL_LockYUVOverlay (overlay);
-    overlay->pixels [0] = base;
-    overlay->pixels [1] = base + (frameWidth * frameHeight);
-    overlay->pixels [2] = base + (frameWidth * frameHeight * 5/4);
-    SDL_UnlockYUVOverlay (overlay);
+    /* SDL interprets each pixel as a 32-bit number, so our masks must depend
+       on the endianness (byte order) of the machine */
+#if SDL_BYTEORDER == SDL_BIG_ENDIAN
+    rmask = 0xff000000;
+    gmask = 0x00ff0000;
+    bmask = 0x0000ff00;
+    amask = 0x000000ff;
+#else
+    rmask = 0x000000ff;
+    gmask = 0x0000ff00;
+    bmask = 0x00ff0000;
+    amask = 0xff000000;
+#endif
+
+    surface =
+      SDL_CreateRGBSurfaceFrom ((void *) gdk_pixbuf_get_pixels (zoomed_pic),
+				zoomed_width, zoomed_height, 24,
+				zoomed_width * 3, rmask, gmask, bmask, amask);
+
+
+    blit_conf = SDL_DisplayFormat (surface);
 
     dest.x = (int) (screen->w - zoomed_width) / 2;
     dest.y = (int) (screen->h - zoomed_height) / 2;
     dest.w = zoomed_width;
     dest.h = zoomed_height;
-    
-    SDL_LockYUVOverlay (overlay);
-    SDL_DisplayYUVOverlay (overlay, &dest);    
-    SDL_UnlockYUVOverlay (overlay);
-    
+
+    SDL_BlitSurface (blit_conf, NULL, screen, &dest);
+    SDL_UpdateRect(screen, 0, 0, 640, 480);
+
+    SDL_FreeSurface (surface);
+    SDL_FreeSurface (blit_conf);
     sdl_mutex.Signal ();
     gnomemeeting_threads_leave ();
   }
@@ -540,24 +522,10 @@ BOOL GDKVideoOutputDevice::Redraw (const void * frame)
   }
 
 
-  if (device_id == 0) {
-    received_frame_number++;
-  }
-
-
-  if (device_id == 1) {
-    transmitted_frame_number++;
-  }
-
-
   gnomemeeting_threads_enter ();
-
-
   g_object_unref (G_OBJECT (src_pic));
   if (unref) 
     g_object_unref (G_OBJECT (zoomed_pic));
-  
-
   gnomemeeting_threads_leave ();
 
   redraw_mutex.Signal ();
@@ -566,12 +534,58 @@ BOOL GDKVideoOutputDevice::Redraw (const void * frame)
 }
 
 
-BOOL GDKVideoOutputDevice::WriteLineSegment(int x, int y, unsigned len, 
-					    const BYTE * data)
+PStringList GDKVideoOutputDevice::GetDeviceNames() const
+{
+  PStringList  devlist;
+  devlist.AppendString(GetDeviceName());
+
+  return devlist;
+}
+
+
+BOOL GDKVideoOutputDevice::IsOpen ()
 {
-  PINDEX offs = 3 * (x + (y * frameWidth));
-  memcpy(buffer.GetPointer() + offs, data, len*3);
   return TRUE;
 }
 
 
+BOOL GDKVideoOutputDevice::SetFrameData(
+					unsigned x,
+					unsigned y,
+					unsigned width,
+					unsigned height,
+					const BYTE * data,
+					BOOL endFrame)
+{
+  if (x+width > frameWidth || y+height > frameHeight)
+    return FALSE;
+
+  if (!endFrame)
+    return FALSE;
+
+  frameStore.SetSize (width * height * 3);
+  
+  if (converter)
+    converter->Convert (data, frameStore.GetPointer ());
+  
+  EndFrame ();
+  
+  return TRUE;
+}
+
+
+BOOL GDKVideoOutputDevice::EndFrame()
+{
+  Redraw ();
+  
+  return TRUE;
+}
+
+
+BOOL GDKVideoOutputDevice::SetColourFormat (const PString & colour_format)
+{
+  if (colour_format == "BGR24")
+    return PVideoOutputDevice::SetColourFormat (colour_format);
+
+  return FALSE;  
+}
