@@ -49,20 +49,13 @@
 
 
 
-class GDKVideoOutputDevice : public PVideoOutputDeviceRGB
+class GDKVideoOutputDevice : public PVideoOutputDevice
 {
-  PCLASSINFO(GDKVideoOutputDevice, PVideoOutputDeviceRGB);
+  PCLASSINFO(GDKVideoOutputDevice, PVideoOutputDevice);
 
 
   public:
 
-  /* DESCRIPTION  :  The constructor.
-   * BEHAVIOR     :  Setup parameters.
-   * PRE          :  GmWindow is a valid pointer to a valid
-   *                 GmWindow structure.
-   */
-  GDKVideoOutputDevice (GmWindow *);
-    
     
   /* DESCRIPTION  :  The constructor.
    * BEHAVIOR     :  Setups the parameters, 
@@ -135,7 +128,12 @@ class GDKVideoOutputDevice : public PVideoOutputDeviceRGB
    * PRE          :  /
    */
   BOOL EndFrame();
+
+
+  BOOL Start () {return TRUE;};
   
+  BOOL Stop () {return TRUE;};
+    
  protected:
 
 
@@ -150,7 +148,8 @@ class GDKVideoOutputDevice : public PVideoOutputDeviceRGB
   int display_config; /* Current display : local or remote or both */
 
   PMutex redraw_mutex;
-
+  PBYTEArray frameStore;
+  
 #ifdef HAS_SDL
   SDL_Surface *screen;
   SDL_Overlay *overlay;
@@ -162,7 +161,8 @@ class GDKVideoOutputDevice : public PVideoOutputDeviceRGB
 
   enum {REMOTE, LOCAL};
 
+  static int devices_nbr;
+  
   GmWindow *gw;
 };
-
 #endif
