@@ -43,7 +43,11 @@
 #include "endpoint.h"
 
 
-/* The main gnomeMeeting class */
+/**
+ * COMMON NOTICE: The Application must be initialized with Init after its
+ * creation.
+ */
+
 class GnomeMeeting : public PProcess
 {
   PCLASSINFO(GnomeMeeting, PProcess);
@@ -79,12 +83,21 @@ class GnomeMeeting : public PProcess
   void Disconnect (H323Connection::CallEndReason
 		   = H323Connection::EndedByLocalUser);
 
+
+  /* DESCRIPTION  :  /
+   * BEHAVIOR     :  Init the endpoint component of the application.
+   * PRE          :  /
+   */
+  void Init ();
+
   
   /* DESCRIPTION  :  /
-   * BEHAVIOR     :  Detects the available audio devices, audio mixers,
-   *                 and video devices and puts the result in the internal
-   *                 GmWindow structure. Returns FALSE if no audio device
-   *                 is detected.
+   * BEHAVIOR     :  Detects the available audio and video managers
+   *                 and audio, video devices corresponding to the managers
+   *                 selected in GConf and puts the result in the internal
+   *                 GmWindow structure. Returns FALSE if no audio manager
+   *                 is detected. Returns TRUE in other cases, even if no
+   *                 devices are found.
    * PRE          :  /
    */
   BOOL DetectDevices ();
@@ -164,14 +177,9 @@ class GnomeMeeting : public PProcess
   GMH323EndPoint *Endpoint (void);
   
 
-  /* DESCRIPTION  :  /
-   * BEHAVIOR     :  Initializes the GnomeMeeting application.
-   *                 (video grabber, endpoint, ILS, gatekeeper registering).
-   * PRE          :  /
-   */
-  void InitComponents (); 
-
+  static GnomeMeeting *Process ();
 
+  
   /* DESCRIPTION  :  /
    * BEHAVIOR     :  Builds the GUI of GnomeMeeting. GConf, GNOME
    *                 and GTK need to have been initialized before.
@@ -198,7 +206,9 @@ class GnomeMeeting : public PProcess
   GmRtpData *rtp;
 
   PMutex ep_var_mutex;
-  int call_number; 
+  int call_number;
+
+  static GnomeMeeting *GM;
 };
 
 #endif
