@@ -17,7 +17,7 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
  *
- * GnomeMeting is licensed under the GPL license and as a special exception,
+ * GnomeMeeting is licensed under the GPL license and as a special exception,
  * you have permission to link or otherwise combine this program with the
  * programs OpenH323 and Pwlib, and distribute the combination, without
  * applying the requirements of the GNU GPL to the OpenH323 program, as long
@@ -41,17 +41,15 @@
 #include "main_window.h"
 #include "gnomemeeting.h"
 #include "chat_window.h"
-#include "ldap_window.h"
 #include "config.h"
-#include "ils.h"
 #include "misc.h"
 #include "toolbar.h"
-#include "menu.h"
 #include "callbacks.h"
-#include "sound_handling.h"
-
 #include "tray.h"
+#include "lid.h"
+
 #include "dialog.h"
+#include "gmentrydialog.h"
 #include "stock-icons.h"
 #include "gconf_widgets_extensions.h"
 
@@ -64,8 +62,6 @@
 #include <bonobo/bonobo-listener.h>
 #endif
 
-#include <stdlib.h>
-
 #ifndef WIN32
 #include <gdk/gdkx.h>
 #endif
@@ -74,6 +70,9 @@
 #include <libintl.h>
 #endif
 
+#include <libxml/parser.h>
+
+
 #define ACT_IID "OAFIID:GNOME_gnomemeeting_Factory"
 
 
@@ -81,8 +80,11 @@
 extern GtkWidget *gm;
 
 
-static void video_window_shown_cb (GtkWidget *, gpointer);
-static gboolean stats_drawing_area_exposed (GtkWidget *, gpointer data);
+static void video_window_shown_cb (GtkWidget *,
+				   gpointer);
+
+static gboolean stats_drawing_area_exposed (GtkWidget *,
+					    gpointer data);
 
 #ifndef DISABLE_GNOME
 static gboolean gnomemeeting_invoke_factory (int, char **);
@@ -573,7 +575,7 @@ main_notebook_page_changed (GtkNotebook *notebook, GtkNotebookPage *page,
 
   GmWindow *gw = GnomeMeeting::Process ()->GetMainWindow ();
 
-  gconf_client_set_int (client, VIEW_KEY "control_panel_section",
+  gconf_client_set_int (client, USER_INTERFACE_KEY "main_window/control_panel_section",
 			gtk_notebook_get_current_page (GTK_NOTEBOOK (gw->main_notebook)), 0);
 }
 
@@ -734,17 +736,18 @@ contrast_changed (GtkAdjustment *adjustment, gpointer data)
  **/
 static void 
 dialpad_button_clicked (GtkButton *button, gpointer data)
-{ 
+{
+  GtkWidget *label = NULL;
   const char *button_text = NULL;
-  PString dtmf;
-  
-  button_text = gtk_button_get_label (GTK_BUTTON (button));
-  dtmf = button_text;
 
-  dtmf.Replace ("_", "");
-  
-  if (!dtmf.IsEmpty ())
-    gnomemeeting_dialpad_event (dtmf);
+  label = gtk_bin_get_child (GTK_BIN (button));
+  button_text = gtk_label_get_text (GTK_LABEL (label));
+
+  if (button_text
+      && strcmp (button_text, "")
+      && strlen (button_text) > 1
+      && button_text [0])
+    gnomemeeting_dialpad_event (button_text [0]);
 }
 
 
@@ -773,91 +776,82 @@ gm_quit_callback (GtkWidget *widget, GdkEvent *event,
 
 
 /* The functions */
-void
-gnomemeeting_main_window_enable_statusbar_progress (gboolean i)
-{
-  GmWindow *gw = GnomeMeeting::Process ()->GetMainWindow ();
-  
-  if (i) {
-    
-
-    gtk_widget_show (gw->progressbar);
-  }
-  else {
-
-
-    gtk_widget_hide (gw->progressbar);
-  }    
-}
-
-
-void gnomemeeting_dialpad_event (const char *key)
+void gnomemeeting_dialpad_event (const char d)
 {
   GMH323EndPoint *endpoint = NULL;
+  H323Connection *connection = NULL;
 
-  const gchar *url = NULL;
-  gchar *button_text = NULL;
+#ifdef HAS_IXJ
+  GMLid *lid = NULL;
+#endif
   
+  PString url;
   PString new_url;
-  PString dtmf;
 
+  char dtmf = d;
+  gchar *msg = NULL;
+  
   GmWindow *gw = NULL;
 
   gw = GnomeMeeting::Process ()->GetMainWindow ();
   endpoint = GnomeMeeting::Process ()->Endpoint ();
 
-  button_text = (gchar *) key;
-  url = gtk_entry_get_text (GTK_ENTRY (GTK_COMBO (gw->combo)->entry)); 
+  if (gw->transfer_call_popup)
+    url = gm_entry_dialog_get_text (GM_ENTRY_DIALOG (gw->transfer_call_popup));
+  else
+    url = gtk_entry_get_text (GTK_ENTRY (GTK_COMBO (gw->combo)->entry)); 
 
-  if (button_text) {
+  
+  if (endpoint->GetCallingState () == GMH323EndPoint::Standby) {
 
-    dtmf = PString (button_text);
-    
     /* Replace the * by a . */
-    if (!strcmp (button_text, "*")) 
-      button_text = g_strdup (".");
-
-    if (endpoint && endpoint->GetCallingState () == GMH323EndPoint::Standby) {
-
-      new_url = url + PString (button_text);
-
-      if (!strcmp (".", button_text)) 
-	g_free (button_text);
-
-      gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (gw->combo)->entry), new_url);
-    }
-
-    
-    /* Now we send the pressed key as UserInput */
-    if (endpoint) {
-        
-      if (endpoint->GetCallingState () == GMH323EndPoint::Connected) {
-            
-	gdk_threads_leave ();
-	H323Connection *connection = 
-	  endpoint->FindConnectionWithLock (endpoint->GetCurrentCallToken ());
-            
-	if (connection) {
-
-	  connection->SendUserInput (dtmf);
-	  connection->Unlock ();
-	}
-	gdk_threads_enter ();
-      }
-
-#ifdef HAS_IXJ
-      GMLid *lid = NULL;
+    if (dtmf == '*') 
+      dtmf = '.';
+  }
       
-      lid = endpoint->GetLid ();
+  new_url = PString (url) + dtmf;
 
-      if (lid) {
-	
-	lid->RingLine (4);
-	lid->Unlock ();
-      }
-#endif
+  if (gw->transfer_call_popup)
+    gm_entry_dialog_set_text (GM_ENTRY_DIALOG (gw->transfer_call_popup),
+			      new_url);
+  else 
+    gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (gw->combo)->entry), new_url);
+
+  if (dtmf == '#' && gw->transfer_call_popup)
+    gtk_dialog_response (GTK_DIALOG (gw->transfer_call_popup),
+			 GTK_RESPONSE_ACCEPT);
+  
+  if (endpoint->GetCallingState () == GMH323EndPoint::Connected
+      && !gw->transfer_call_popup) {
+
+    gdk_threads_leave ();
+    connection = 
+      endpoint->FindConnectionWithLock (endpoint->GetCurrentCallToken ());
+            
+    if (connection) {
+
+      msg = g_strdup_printf (_("Sent dtmf %c"), dtmf);
+      
+      connection->SendUserInput (dtmf);
+      connection->Unlock ();
+    }
+    gdk_threads_enter ();
+
+    if (msg) {
+
+      gnomemeeting_statusbar_flash (gw->statusbar, msg);
+      g_free (msg);
     }
   }
+
+#ifdef HAS_IXJ
+  lid = endpoint->GetLid ();
+  if (lid) {
+
+    lid->StopTone (0);
+    lid->Unlock ();
+  }
+#endif
 }
 
 
@@ -947,8 +941,6 @@ gnomemeeting_main_window_new (GmWindow *gw)
   GtkWidget *left_toolbar = NULL;
 
   int main_notebook_section = 0;
-  int x = GM_QCIF_WIDTH;
-  int y = GM_QCIF_HEIGHT;
 
   GmTextChat *chat = NULL;
   GConfClient *client = NULL;
@@ -983,18 +975,13 @@ gnomemeeting_main_window_new (GmWindow *gw)
   gtk_widget_show (hbox);
 
   
-  gw->progressbar = gtk_progress_bar_new ();
-  gtk_widget_set_size_request (GTK_WIDGET (gw->progressbar), 25, -1);
-  gtk_box_pack_start (GTK_BOX (hbox), gw->progressbar, 
-		      FALSE, FALSE, 0);
-
   gw->statusbar = gtk_statusbar_new ();
   gtk_statusbar_set_has_resize_grip (GTK_STATUSBAR (gw->statusbar), FALSE);
   gtk_box_pack_start (GTK_BOX (hbox), gw->statusbar, 
 		      TRUE, TRUE, 0);
 
   if (gconf_client_get_bool (client, 
-			     VIEW_KEY "show_status_bar", 0))
+			     USER_INTERFACE_KEY "main_window/show_status_bar", 0))
     gtk_widget_show (GTK_WIDGET (gw->statusbar));
   else
     gtk_widget_hide (GTK_WIDGET (gw->statusbar));
@@ -1069,7 +1056,7 @@ gnomemeeting_main_window_new (GmWindow *gw)
 		    6, 6); 
 
   main_notebook_section = 
-    gconf_client_get_int (client, VIEW_KEY "control_panel_section", 0);
+    gconf_client_get_int (client, USER_INTERFACE_KEY "main_window/control_panel_section", 0);
 
   if (main_notebook_section != GM_MAIN_NOTEBOOK_HIDDEN) {
 
@@ -1117,17 +1104,15 @@ gnomemeeting_main_window_new (GmWindow *gw)
 
   
   /* The 2 video window popups */
-  x = gconf_client_get_int (client, VIDEO_DISPLAY_KEY "local_video_width", NULL);
-  y = gconf_client_get_int (client, VIDEO_DISPLAY_KEY "local_video_height", NULL);
   gw->local_video_window =
-    gnomemeeting_video_window_new (_("Local Video"), gw->local_video_image,
-				   x, y);
-
-  x = gconf_client_get_int (client, VIDEO_DISPLAY_KEY "remote_video_width", NULL);
-  y = gconf_client_get_int (client, VIDEO_DISPLAY_KEY "remote_video_height", NULL);
+    gnomemeeting_video_window_new (_("Local Video"),
+				   gw->local_video_image,
+				   "local_video_window");
   gw->remote_video_window =
-    gnomemeeting_video_window_new (_("Remote Video"), gw->remote_video_image,
-				   x, y);
+    gnomemeeting_video_window_new (_("Remote Video"),
+				   gw->remote_video_image,
+				   "remote_video_window");
+  
   gnomemeeting_init_main_window_logo (gw->main_video_image);
 
   g_signal_connect (G_OBJECT (gw->local_video_window), "show", 
@@ -1157,7 +1142,7 @@ gnomemeeting_main_window_new (GmWindow *gw)
  		    (GtkAttachOptions) (GTK_FILL | GTK_EXPAND),
  		    6, 6);
   if (gconf_client_get_bool 
-      (client, VIEW_KEY "show_chat_window", 0))
+      (client, USER_INTERFACE_KEY "main_window/show_chat_window", 0))
     gtk_widget_show_all (GTK_WIDGET (gw->chat_window));
   
   gtk_widget_set_size_request (GTK_WIDGET (gw->main_notebook),
@@ -1264,7 +1249,7 @@ void gnomemeeting_init_main_window_stats ()
 }
 
 
-/**
+/*
  * DESCRIPTION  :  /
  * BEHAVIOR     :  Builds the dialpad part of the main window.
  * PRE          :  /
@@ -1275,53 +1260,49 @@ void gnomemeeting_init_main_window_dialpad (GtkAccelGroup *accel)
   GtkWidget *table = NULL;
   GtkWidget *button = NULL;
 
-  gchar *button_text = NULL;
   int i = 0;
-  int j = 0;
-  int j2 = 0;
 
-  GmWindow *gw = GnomeMeeting::Process ()->GetMainWindow ();
+  GmWindow *gw = NULL;
+
+  char *key_n [] = { "1", "2", "3", "4", "5", "6", "7", "8", "9",
+		     "*", "0", "#"};
+  char *key_a []= { "  ", "abc", "def", "ghi", "jkl", "mno", "pqrs", "tuv",
+		   "wxyz", "  ", "  ", "  "};
+
+  gchar *text_label = NULL;
+  
+  gw = GnomeMeeting::Process ()->GetMainWindow ();
 
   table = gtk_table_new (4, 3, TRUE);
-  gtk_container_set_border_width (GTK_CONTAINER (table), 3);
+  gtk_container_set_border_width (GTK_CONTAINER (table), 6);
+  
+  for (i = 0 ; i < 12 ; i++) {
 
-  for (i = 1 ; i < 4 ; i++) {
-    for (j = 0 ; j < 4 ; j++) {
-      if (j == 0) {
+    label = gtk_label_new (NULL);
+    text_label =
+      g_strdup_printf ("%s<sub><span size=\"small\">%s</span></sub>",
+		       key_n [i], key_a [i]);
+    gtk_label_set_markup (GTK_LABEL (label), text_label); 
+    button = gtk_button_new ();
+    gtk_container_set_border_width (GTK_CONTAINER (button), 0);
+    gtk_container_add (GTK_CONTAINER (button), label);
+    
+    gtk_table_attach (GTK_TABLE (table), GTK_WIDGET (button), 
+		      i%3, i%3+1, i/3, i/3+1,
+		      (GtkAttachOptions) (GTK_FILL | GTK_EXPAND),
+		      (GtkAttachOptions) (GTK_FILL),
+		      1, 1);
+    
+    g_signal_connect (G_OBJECT (button), "clicked",
+		      GTK_SIGNAL_FUNC (dialpad_button_clicked), NULL);
 
-	if (i == 1)
-	  button_text = g_strdup ("_*");
-	else if (i == 2)
-	  button_text = g_strdup ("_0");
-	else if (i == 3)
-	  button_text = g_strdup ("_#");
-	
-	j2 = 3;
-      }
-      else {
-
-	j2 = j - 1;
-	button_text = g_strdup_printf ("_%d", (j - 1) * 3 + i);
-      }
-
-      button = gtk_button_new_with_mnemonic (button_text);
-
-      gtk_table_attach (GTK_TABLE (table), GTK_WIDGET (button), 
-			i - 1, i, j2, j2+1,
-			(GtkAttachOptions) (GTK_FILL | GTK_EXPAND),
-			(GtkAttachOptions) (GTK_FILL | GTK_EXPAND),
-			1, 1);
-      
-      g_signal_connect (G_OBJECT (button), "clicked",
-			GTK_SIGNAL_FUNC (dialpad_button_clicked), NULL);
-
-      g_free (button_text);
-    }
+    g_free (text_label);
   }
   
   label = gtk_label_new (_("Dialpad"));
 
-  gtk_notebook_append_page (GTK_NOTEBOOK (gw->main_notebook), table, label);
+  gtk_notebook_append_page (GTK_NOTEBOOK (gw->main_notebook),
+			    table, label);
 }
 
 
@@ -1616,9 +1597,6 @@ int main (int argc, char ** argv, char ** envp)
 #endif
 
   
-  gnomemeeting_warning_dialog (NULL, "WARNING!", "You are using a CVS version of GnomeMeeting, use it at your own risk!");
-
-  
   /* Upgrade the preferences */
   gnomemeeting_gconf_upgrade ();
 
