@@ -51,7 +51,8 @@
 
 #include <gdk/gdkx.h>
 #include <X11/Xlib.h>
-                                                                                
+
+
 /* Declarations */
 extern GtkWidget *gm;
 
@@ -100,8 +101,12 @@ gnomemeeting_button_new (const char *lbl,
 
 
 void 
-gnomemeeting_log_insert (GtkWidget *text_view, gchar *text)
+gnomemeeting_log_insert (GtkWidget *text_view,
+			 const char *format,
+			 ...)
 {
+  va_list args;
+  
   GtkTextIter end;
   GtkTextMark *mark;
   GtkTextBuffer *buffer;
@@ -109,6 +114,14 @@ gnomemeeting_log_insert (GtkWidget *text_view, gchar *text)
   time_t *timeptr;
   char *time_str;
   gchar *text_buffer = NULL;
+  char buf [1025];
+
+  if (!text_view || !format)
+    return;
+      
+  va_start (args, format);
+
+  vsnprintf (buf, 1024, format, args);
 
   time_str = (char *) malloc (21);
   timeptr = new (time_t);
@@ -116,7 +129,7 @@ gnomemeeting_log_insert (GtkWidget *text_view, gchar *text)
   time (timeptr);
   strftime(time_str, 20, "%H:%M:%S", localtime (timeptr));
 
-  text_buffer = g_strdup_printf ("%s %s\n", time_str, text);
+  text_buffer = g_strdup_printf ("%s %s\n", time_str, buf);
 
   buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (text_view));
 
@@ -358,15 +371,16 @@ gnomemeeting_statusbar_push (GtkWidget *widget, const char *msg, ...)
 GtkWidget *
 gnomemeeting_video_window_new (gchar *title, 
 			       GtkWidget *&image,
-			       int x, 
-			       int y)
+			       gchar *window_name)
 {
   GtkWidget *vbox = NULL;
   GtkWidget *window = NULL;
 
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_window_set_title (GTK_WINDOW (window), title);
-
+  g_object_set_data_full (G_OBJECT (window), "window_name",
+			  g_strdup (window_name), g_free);
+  
   vbox = gtk_vbox_new (0, FALSE);
   image = gtk_image_new ();
 
@@ -376,9 +390,11 @@ gnomemeeting_video_window_new (gchar *title,
   gtk_container_add (GTK_CONTAINER (window), vbox);
   gtk_widget_realize (image);
 
-  gtk_widget_set_size_request (GTK_WIDGET (image), x, y);
-  gtk_window_set_resizable (GTK_WINDOW (window), false);
+  gtk_widget_set_size_request (GTK_WIDGET (image), 176, 144);
+  gtk_window_set_resizable (GTK_WINDOW (window), TRUE);
 
+  gtk_widget_show_all (vbox);
+    
   g_signal_connect (G_OBJECT (window), "delete_event",
 		    G_CALLBACK (gtk_widget_hide_on_delete), 0);
 
