@@ -76,10 +76,13 @@ gnomemeeting_button_new (const char *,
 /* DESCRIPTION  :  /
  * BEHAVIOR     :  Add text (gchar *) with timestamps into the given 
  *                 GtkTextView.
- * PRE          :  The text to add, and the text view to add the text into.
+ * PRE          :  The text to add (printf compatible),
+ *                 and the text view to add the text into.
  */
 void 
-gnomemeeting_log_insert (GtkWidget *, gchar *);
+gnomemeeting_log_insert (GtkWidget *,
+			 const char *,
+			 ...);
 
 
 /* DESCRIPTION  :  /
@@ -120,11 +123,13 @@ gnomemeeting_statusbar_push (GtkWidget *, const char *, ...);
 
 /* DESCRIPTION   :  /
  * BEHAVIOR      : Creates a video window.
- * PRE           : The title of the window, the drawing area, and the width and
- *                 height.
+ * PRE           : The title of the window, the drawing area and the window
+ *                 name that will be used by gnomemeeting_window_show/hide.
  */
 GtkWidget *
-gnomemeeting_video_window_new (gchar *, GtkWidget *&, int, int);
+gnomemeeting_video_window_new (gchar *,
+			       GtkWidget *&,
+			       gchar *);
 
 
 /* DESCRIPTION   :  /
