@@ -46,6 +46,7 @@
 #include "misc.h"
 #include "urlhandler.h"
 #include "codec_info.h"
+#include "lid.h"
 
 #include "dialog.h"
 #include "gnome_prefs_window.h"
@@ -119,12 +120,18 @@ static void gnomemeeting_init_pref_window_sound_events (GtkWidget *,
 static void gnomemeeting_init_pref_window_call_forwarding (GtkWidget *,
 							   GtkWidget *);
 
+static void gnomemeeting_init_pref_window_call_options (GtkWidget *,
+							GtkWidget *);
+
 static void gnomemeeting_init_pref_window_h323_advanced (GtkWidget *,
 							 GtkWidget *);
 
 static void gnomemeeting_init_pref_window_gatekeeper (GtkWidget *,
 						      GtkWidget *);
 
+static void gnomemeeting_init_pref_window_gateway (GtkWidget *,
+						   GtkWidget *);
+
 static void gnomemeeting_init_pref_window_nat (GtkWidget *,
 					       GtkWidget *);
 
@@ -250,7 +257,7 @@ static void codecs_list_button_clicked_callback (GtkWidget *widget,
      set the selected codec one row above its current plance */
   codecs_data =
     gconf_client_get_list (client, 
-			   AUDIO_CODECS_KEY "codecs_list", 
+			   AUDIO_CODECS_KEY "list", 
 			   GCONF_VALUE_STRING, NULL);
 
   codecs_data_iter = codecs_data;
@@ -312,7 +319,7 @@ static void codecs_list_button_clicked_callback (GtkWidget *widget,
 
 
   gconf_client_set_list (client, 
-			 AUDIO_CODECS_KEY "codecs_list", 
+			 AUDIO_CODECS_KEY "list", 
 			 GCONF_VALUE_STRING, codecs_data, NULL);
 
   
@@ -626,7 +633,7 @@ codecs_list_fixed_toggled (GtkCellRendererToggle *cell,
      one row above its current plance */
   codecs_data = 
     gconf_client_get_list (client, 
-			   AUDIO_CODECS_KEY "codecs_list", 
+			   AUDIO_CODECS_KEY "list", 
 			   GCONF_VALUE_STRING, NULL);
 
   /* We are reading the codecs */
@@ -663,7 +670,7 @@ codecs_list_fixed_toggled (GtkCellRendererToggle *cell,
   
   g_slist_free (codecs_data_element);
   
-  gconf_client_set_list (client, AUDIO_CODECS_KEY "codecs_list",
+  gconf_client_set_list (client, AUDIO_CODECS_KEY "list",
 			 GCONF_VALUE_STRING, codecs_data, NULL);
 
   g_slist_free (codecs_data);
@@ -727,7 +734,9 @@ gnomemeeting_prefs_window_sound_events_list_build (GtkTreeView *tree_view)
 
 
 void
-gnomemeeting_codecs_list_build (GtkListStore *codecs_list_store) 
+gnomemeeting_codecs_list_build (GtkListStore *codecs_list_store,
+				BOOL is_quicknet,
+				BOOL software_supported) 
 {
   GtkTreeView *tree_view = NULL;
   GtkTreeSelection *selection = NULL;
@@ -741,20 +750,14 @@ gnomemeeting_codecs_list_build (GtkListStore *codecs_list_store)
 
   gchar *cselect_row = NULL;
   gchar *selected_codec = NULL;
-  gchar *quicknet = NULL;
     
   GMH323CodecInfo cdec;
 
-  PString dev;
   PString codec;
     
   GSList *codecs_data = NULL;
-  GConfClient *client = gconf_client_get_default ();
 
-  codecs_data = 
-    gconf_client_get_list (client, 
-			   AUDIO_CODECS_KEY "codecs_list", 
-			   GCONF_VALUE_STRING, NULL);
+  codecs_data = gconf_get_string_list (AUDIO_CODECS_KEY "list");
 
   selected_codec =
     (gchar *) g_object_get_data (G_OBJECT (codecs_list_store), 
@@ -767,29 +770,20 @@ gnomemeeting_codecs_list_build (GtkListStore *codecs_list_store)
 
     gchar **couple = g_strsplit ((gchar *) codecs_data->data, "=", 0);
 
-    if ((couple [0]) && (couple [1])) {
+    if (couple [0] && couple [1]) {
 
-      dev = gconf_get_string (AUDIO_DEVICES_KEY "input_device");
-      cout << "FIX ME here for Quicknet" << endl << flush;
       codec = PString (couple [0]);
-      if (quicknet)
-	dev = PString (quicknet);
-      
-      if (codec.Find ("G.723.1") != P_MAX_INDEX &&
-	  dev.Find ("phone") == P_MAX_INDEX) {
-	
+
+      if ((!is_quicknet && codec.Find ("G.723.1") != P_MAX_INDEX)
+	  || (is_quicknet && !software_supported
+	      && codec.Find ("G.723.1") != P_MAX_INDEX
+	      && codec.Find ("G.711") != P_MAX_INDEX))
 	gnomemeeting_codecs_list_add (list_iter, codecs_list_store, 
 				      couple [0], 0, false, "darkgray");
-
-      }
-      else {
-
+      else
 	gnomemeeting_codecs_list_add (list_iter, codecs_list_store, 
 				      couple [0], atoi (couple [1]),
 				      true, "black");
-      }
-      
-      g_free (quicknet);
     }
 
     
@@ -928,7 +922,7 @@ gnomemeeting_init_pref_window_interface (GtkWidget *window,
     gnome_prefs_subsection_new (window, container,
 				_("GnomeMeeting GUI"), 2, 2);
 
-  gnome_prefs_toggle_new (subsection, _("_Show splash screen"), VIEW_KEY "show_splash", _("If enabled, the splash screen will be displayed when GnomeMeeting starts."), 0);
+  gnome_prefs_toggle_new (subsection, _("_Show splash screen"), USER_INTERFACE_KEY "show_splash_screen", _("If enabled, the splash screen will be displayed when GnomeMeeting starts."), 0);
 
   gnome_prefs_toggle_new (subsection, _("Start _hidden"), USER_INTERFACE_KEY "start_hidden", _("If enabled, GnomeMeeting will start hidden provided that the notification area is present in the GNOME panel."), 1);
 
@@ -949,7 +943,7 @@ gnomemeeting_init_pref_window_interface (GtkWidget *window,
   subsection =
     gnome_prefs_subsection_new (window, container, _("Text Chat"), 1, 1);
   
-  gnome_prefs_toggle_new (subsection, _("Automatically clear the text chat at the end of calls"), GENERAL_KEY "auto_clear_text_chat", _("If enabled, the text chat will automatically be cleared at the end of calls."), 0);
+  gnome_prefs_toggle_new (subsection, _("Automatically clear the text chat at the end of calls"), USER_INTERFACE_KEY "auto_clear_text_chat", _("If enabled, the text chat will automatically be cleared at the end of calls."), 0);
 }
 
 
@@ -971,11 +965,11 @@ gnomemeeting_init_pref_window_directories (GtkWidget *window,
 
 
   /* Add all the fields */                                                     
-  gnome_prefs_entry_new (subsection, _("User directory:"), LDAP_KEY "ldap_server", _("The user directory server to register with."), 0, true);
+  gnome_prefs_entry_new (subsection, _("User directory:"), LDAP_KEY "server", _("The user directory server to register with."), 0, true);
 
-  gnome_prefs_toggle_new (subsection, _("Enable _registering"), LDAP_KEY "register", _("If enabled, register with the selected user directory."), 1);
+  gnome_prefs_toggle_new (subsection, _("Enable _registering"), LDAP_KEY "enable_registering", _("If enabled, register with the selected user directory."), 1);
 
-  gnome_prefs_toggle_new (subsection, _("_Publish my details in the users directory when registering"), LDAP_KEY "visible", _("If enabled, your details are shown to people browsing the user directory. If disabled, you are not visible to users browsing the user directory, but they can still use the callto URL to call you."), 2);
+  gnome_prefs_toggle_new (subsection, _("_Publish my details in the users directory when registering"), LDAP_KEY "show_details", _("If enabled, your details are shown to people browsing the user directory. If disabled, you are not visible to users browsing the user directory, but they can still use the callto URL to call you."), 2);
 }
 
 
@@ -1004,9 +998,32 @@ gnomemeeting_init_pref_window_call_forwarding (GtkWidget *window,
   
   gnome_prefs_toggle_new (subsection, _("_Always forward calls to the given host"), CALL_FORWARDING_KEY "always_forward", _("If enabled, all incoming calls will be forwarded to the host that is specified in the field above."), 1);
 
-  gnome_prefs_toggle_new (subsection, _("Forward calls to the given host if _no answer"), CALL_FORWARDING_KEY "no_answer_forward", _("If enabled, all incoming calls will be forwarded to the host that is specified in the field above if you do not answer the call."), 2);
+  gnome_prefs_toggle_new (subsection, _("Forward calls to the given host if _no answer"), CALL_FORWARDING_KEY "forward_on_no_answer", _("If enabled, all incoming calls will be forwarded to the host that is specified in the field above if you do not answer the call."), 2);
 
-  gnome_prefs_toggle_new (subsection, _("Forward calls to the given host if _busy"), CALL_FORWARDING_KEY "busy_forward", _("If enabled, all incoming calls will be forwarded to the host that is specified in the field above if you already are in a call or if you are in Do Not Disturb mode."), 3);
+  gnome_prefs_toggle_new (subsection, _("Forward calls to the given host if _busy"), CALL_FORWARDING_KEY "forward_on_busy", _("If enabled, all incoming calls will be forwarded to the host that is specified in the field above if you already are in a call or if you are in Do Not Disturb mode."), 3);
+}
+
+
+/* BEHAVIOR     :  It builds the container for call control,
+ *                 and returns it.
+ * PRE          :  /                                             
+ */                                                                            
+static void
+gnomemeeting_init_pref_window_call_options (GtkWidget *window,
+					    GtkWidget *container)
+{
+  GtkWidget *subsection = NULL;
+
+  GmPrefWindow *pw = NULL;
+
+  pw = GnomeMeeting::Process ()->GetPrefWindow ();
+  
+  subsection = gnome_prefs_subsection_new (window, container,
+					   _("Calls Clearing"), 1, 1);
+
+
+  /* Add all the fields */
+  gnome_prefs_toggle_new (subsection, _("Automatically _clear calls after 30 seconds of inactivity"), CALL_OPTIONS_KEY "clear_inactive_calls", _("If enabled, calls for which no audio and video has been received in the last 30 seconds are automatically cleared."), 1);  
 }
 
 
@@ -1122,7 +1139,7 @@ gnomemeeting_init_pref_window_sound_events (GtkWidget *window,
   entry = gtk_entry_new ();
   gtk_box_pack_start (GTK_BOX (hbox), entry, FALSE, FALSE, 2);
   
-  button = gtk_button_new_with_label (_("Choose a file to play"));
+  button = gtk_button_new_from_stock (GTK_STOCK_OPEN);
   gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 2);
 
   g_signal_connect (G_OBJECT (button), "clicked",
@@ -1176,23 +1193,22 @@ gnomemeeting_init_pref_window_h323_advanced (GtkWidget *window,
   /* Packing widget */
   subsection =
     gnome_prefs_subsection_new (window, container,
-				_("H.323 Version 2 Settings"), 2, 1);
+				_("H.323 Version 2 Settings"), 3, 1);
 
   /* The toggles */
-  pw->ht =
-    gnome_prefs_toggle_new (subsection, _("Enable H.245 _tunnelling"), GENERAL_KEY "h245_tunneling", _("This enables H.245 Tunnelling mode. In H.245 Tunnelling mode H.245 messages are encapsulated into the the H.225 channel (port 1720). This saves one TCP connection during calls. H.245 Tunnelling was introduced in H.323v2 and Netmeeting does not support it. Using both Fast Start and H.245 Tunnelling can crash some versions of Netmeeting."), 0);
+  gnome_prefs_toggle_new (subsection, _("Enable H.245 _tunneling"), H323_ADVANCED_KEY "enable_h245_tunneling", _("This enables H.245 Tunneling mode. In H.245 Tunneling mode H.245 messages are encapsulated into the the H.225 channel (port 1720). This saves one TCP connection during calls. H.245 Tunneling was introduced in H.323v2 and Netmeeting does not support it. Using both Fast Start and H.245 Tunneling can crash some versions of Netmeeting."), 0);
 
-  pw->fs =
-    gnome_prefs_toggle_new (subsection, _("Enable fast _start procedure"), GENERAL_KEY "fast_start", _("Connection will be established in Fast Start mode. Fast Start is a new way to start calls faster that was introduced in H.323v2. It is not supported by Netmeeting and using both Fast Start and H.245 Tunnelling can crash some versions of Netmeeting."), 1);
+   gnome_prefs_toggle_new (subsection, _("Enable _early H.245"), H323_ADVANCED_KEY "enable_early_h245", _("This enables H.245 early in the setup."), 1);
+
+  gnome_prefs_toggle_new (subsection, _("Enable fast _start procedure"), H323_ADVANCED_KEY "enable_fast_start", _("Connection will be established in Fast Start mode. Fast Start is a new way to start calls faster that was introduced in H.323v2. It is not supported by Netmeeting and using both Fast Start and H.245 Tunneling can crash some versions of Netmeeting."), 2);
 
   
   /* Packing widget */                                                         
   subsection =
     gnome_prefs_subsection_new (window, container,
-				_("User Input Capabilities"), 1, 1);
+				_("DTMF Sending"), 1, 1);
 
-  pw->uic =
-    gnome_prefs_int_option_menu_new (subsection, _("T_ype:"), capabilities, GENERAL_KEY "user_input_capability", _("This permits to set the mode for User Input Capabilities. The values can be \"All\", \"None\", \"rfc2833\", \"Signal\" or \"String\" (default is \"All\"). Choosing other values than \"All\", \"String\" or \"rfc2833\" disables the Text Chat."), 0);
+  gnome_prefs_int_option_menu_new (subsection, _("_Send DTMF as:"), capabilities, H323_ADVANCED_KEY "dtmf_sending", _("This permits to set the mode for DTMFs sending. The values can be \"All\", \"None\", \"rfc2833\", \"Signal\" or \"String\" (default is \"All\"). Choosing other values than \"All\", \"String\" or \"rfc2833\" disables the Text Chat."), 0);
 }                               
 
 
@@ -1218,24 +1234,45 @@ gnomemeeting_init_pref_window_gatekeeper (GtkWidget *window,
   subsection = gnome_prefs_subsection_new (window, container,
 					   _("Gatekeeper"), 4, 3);
 
-  gnome_prefs_entry_new (subsection, _("Gatekeeper _ID:"), GATEKEEPER_KEY "gk_id", _("The Gatekeeper identifier to register with."), 1, false);
+  gnome_prefs_entry_new (subsection, _("Gatekeeper _ID:"), H323_GATEKEEPER_KEY "id", _("The Gatekeeper identifier to register with."), 1, false);
 
-  gnome_prefs_entry_new (subsection, _("Gatekeeper _host:"), GATEKEEPER_KEY "gk_host", _("The Gatekeeper host to register with."), 2, false);
+  gnome_prefs_entry_new (subsection, _("Gatekeeper _host:"), H323_GATEKEEPER_KEY "host", _("The Gatekeeper host to register with."), 2, false);
 
-  gnome_prefs_entry_new (subsection, _("Gatekeeper _alias:"), GATEKEEPER_KEY "gk_alias", _("The Gatekeeper alias to use when registering (string, or E164 ID if only 0123456789#)."), 3, false);
+  gnome_prefs_entry_new (subsection, _("Gatekeeper _alias:"), H323_GATEKEEPER_KEY "alias", _("The Gatekeeper alias to use when registering (string, or E164 ID if only 0123456789#)."), 3, false);
 
   entry =
-    gnome_prefs_entry_new (subsection, _("Gatekeeper _password:"), GATEKEEPER_KEY "gk_password", _("The Gatekeeper password to use for H.235 authentication to the Gatekeeper."), 4, false);
+    gnome_prefs_entry_new (subsection, _("Gatekeeper _password:"), H323_GATEKEEPER_KEY "password", _("The Gatekeeper password to use for H.235 authentication to the Gatekeeper."), 4, false);
   gtk_entry_set_visibility (GTK_ENTRY (entry), FALSE);
 
-  gnome_prefs_toggle_new (subsection, _("Register this alias as the primary alias with the gatekeeper"), GATEKEEPER_KEY "register_alias_as_primary", _("Use this option to ensure the above alias is used as the primary alias when registering with a gatekeeper. This may be required if your gatekeeper can only perform authentication using the first alias in the list."), 5);
+  gnome_prefs_toggle_new (subsection, _("Register this alias as the primary alias with the gatekeeper"), H323_GATEKEEPER_KEY "register_alias_as_primary", _("Use this option to ensure the above alias is used as the primary alias when registering with a gatekeeper. This may be required if your gatekeeper can only perform authentication using the first alias in the list."), 5);
   
-  gnome_prefs_int_option_menu_new (subsection, _("Registering method:"), options, GATEKEEPER_KEY "registering_method", _("Registering method to use"), 0);
+  gnome_prefs_int_option_menu_new (subsection, _("Registering method:"), options, H323_GATEKEEPER_KEY "registering_method", _("The registering method to use."), 0);
 
   gnomemeeting_pref_window_add_update_button (container, GTK_STOCK_APPLY, _("_Apply"), GTK_SIGNAL_FUNC (gatekeeper_update_button_clicked), _("Click here to update your Gatekeeper settings."), 0);
 }
 
 
+/* BEHAVIOR     :  It builds the container for the gateway/proxy settings
+ *                 and returns it.
+ * PRE          :  /
+ */
+static void
+gnomemeeting_init_pref_window_gateway (GtkWidget *window,
+				       GtkWidget *container)
+{
+  GtkWidget *subsection = NULL;
+
+
+  /* Add fields for the gatekeeper */
+  subsection = gnome_prefs_subsection_new (window, container,
+					   _("Gateway/Proxy"), 2, 2);
+
+  gnome_prefs_entry_new (subsection, _("Gateway / Proxy host:"), H323_GATEWAY_KEY "host", _("The Gateway host is the host to use to do H.323 calls through a gateway that will relay calls."), 1, false);
+
+  gnome_prefs_toggle_new (subsection, _("Use gateway or proxy"), H323_GATEWAY_KEY "use_gateway", _("Use or not the specified gateway to do calls."), 2);
+}
+
+
 /* BEHAVIOR     :  It builds the container for NAT support
  *                 and returns it.
  * PRE          :  /
@@ -1250,11 +1287,13 @@ gnomemeeting_init_pref_window_nat (GtkWidget *window,
   /* IP translation */
   subsection =
     gnome_prefs_subsection_new (window, container,
-				_("NAT/PAT Router Support"), 2, 1);
+				_("NAT/PAT Router Support"), 3, 1);
 
-  gnome_prefs_toggle_new (subsection, _("Enable IP _translation"), NAT_KEY "ip_translation", _("This enables IP translation. IP translation is useful if GnomeMeeting is running behind a NAT/PAT router. You have to put the public IP of the router in the field below. If you are registered to ils.seconix.com, GnomeMeeting will automatically fetch the public IP using the ILS service. If your router natively supports H.323, you can disable this."), 1);
+  gnome_prefs_toggle_new (subsection, _("Enable IP _translation"), NAT_KEY "enable_ip_translation", _("This enables IP translation. IP translation is useful if GnomeMeeting is running behind a NAT/PAT router. You have to put the public IP of the router in the field below. If you are registered to ils.seconix.com, GnomeMeeting will automatically fetch the public IP using the ILS service. If your router natively supports H.323, you can disable this."), 1);
 
-  gnome_prefs_entry_new (subsection, _("Public _IP of the NAT/PAT router:"), NAT_KEY "public_ip", _("Enter the public IP of your NAT/PAT router if you want to use IP translation. If you are registered to ils.seconix.com, GnomeMeeting will automatically fetch the public IP using the ILS service."), 2, false);
+  gnome_prefs_toggle_new (subsection, _("Enable _automatic IP checking"), NAT_KEY "enable_ip_checking", _("This enables IP checking from seconix.com and fills the IP in the public IP of the NAT/PAT gateway field of GnomeMeeting. The returned IP is only used when IP Translation is enabled. If you disable IP checking, you will have to manually enter the IP of your gateway in the GnomeMeeting preferences."), 2);
+  
+  gnome_prefs_entry_new (subsection, _("Public _IP of the NAT/PAT router:"), NAT_KEY "public_ip", _("Enter the public IP of your NAT/PAT router if you want to use IP translation. If you are registered to ils.seconix.com, GnomeMeeting will automatically fetch the public IP using the ILS service."), 3, false);
 }
 
 
@@ -1280,6 +1319,10 @@ gnomemeeting_init_pref_window_audio_devices (GtkWidget *window,
 		   _("AGC"),
 		   NULL};
 
+  gchar *types_array [] = {_("POTS"),
+			   _("headset"),
+			   NULL};
+
 
   gw = GnomeMeeting::Process ()->GetMainWindow ();
   pw = GnomeMeeting::Process ()->GetPrefWindow ();
@@ -1313,17 +1356,17 @@ gnomemeeting_init_pref_window_audio_devices (GtkWidget *window,
 
 #ifdef HAS_IXJ
   /* The Quicknet devices related options */
-  /*
   subsection = gnome_prefs_subsection_new (window, container,
-					   _("Quicknet Device"), 2, 2);
-
-  gnome_prefs_int_option_menu_new (subsection, _("Echo _cancellation:"), aec, DEVICES_KEY "lid_aec", _("The Automatic Echo Cancellation level: Off, Low, Medium, High, Automatic Gain Compensation. Choosing Automatic Gain Compensation modulates the volume for best quality."), 0);
+					   _("Quicknet Hardware"), 3, 2);
+  
+  gnome_prefs_int_option_menu_new (subsection, _("Echo _cancellation:"), aec, AUDIO_DEVICES_KEY "lid_echo_cancellation_level", _("The Automatic Echo Cancellation level: Off, Low, Medium, High, Automatic Gain Compensation. Choosing Automatic Gain Compensation modulates the volume for best quality."), 0);
 
+  gnome_prefs_int_option_menu_new (subsection, _("Output device type:"), types_array, AUDIO_DEVICES_KEY "lid_output_device_type", _("The output device type is the type of device connected to your Quicknet card. It can be either a POTS (plain old telephone set) or a headset."), 1);
+  
   entry =
-    gnome_prefs_entry_new (subsection, _("Country _code:"), DEVICES_KEY "lid_country", _("The two-letter country code of your country (e.g.: BE, UK, FR, DE, ...)."), 1, false);
+    gnome_prefs_entry_new (subsection, _("Country _code:"), AUDIO_DEVICES_KEY "lid_country_code", _("The two-letter country code of your country (e.g.: BE, UK, FR, DE, ...)."), 2, false);
   gtk_entry_set_max_length (GTK_ENTRY (entry), 2);
-  gtk_widget_set_size_request (GTK_WIDGET (entry), 100, -1);  
-  */
+  gtk_widget_set_size_request (GTK_WIDGET (entry), 100, -1);
 #endif
 
   
@@ -1392,9 +1435,8 @@ gnomemeeting_init_pref_window_video_devices (GtkWidget *window,
   entry =
     gnome_prefs_entry_new (subsection, _("Image:"), VIDEO_DEVICES_KEY "image", _("The image to transmit if \"Picture\" is selected for the video device or if the opening of the device fails. Leave blank to use the default GnomeMeeting logo."), 4, false);
 
-
   /* The file selector button */
-  button = gtk_button_new_with_label (_("Choose a picture"));
+  button = gtk_button_new_from_stock (GTK_STOCK_OPEN);
   gtk_table_attach (GTK_TABLE (subsection), button, 2, 3, 4, 5,
                     (GtkAttachOptions) (GTK_FILL | GTK_EXPAND),
                     (GtkAttachOptions) (GTK_FILL | GTK_EXPAND),
@@ -1404,7 +1446,6 @@ gnomemeeting_init_pref_window_video_devices (GtkWidget *window,
 		    G_CALLBACK (browse_button_clicked_cb),
 		    (gpointer) entry);
 
-
   /* That button will refresh the devices list */
   gnomemeeting_pref_window_add_update_button (container, GTK_STOCK_REFRESH, _("_Detect devices"), GTK_SIGNAL_FUNC (refresh_devices_list_button_clicked), _("Click here to refresh the devices list."), 1);
 }
@@ -1418,6 +1459,8 @@ static void
 gnomemeeting_init_pref_window_audio_codecs (GtkWidget *window,
 					    GtkWidget *container)
 {
+  GMH323EndPoint *ep = NULL;
+  
   GtkWidget *subsection = NULL;
   
   GtkWidget *alignment = NULL;
@@ -1431,11 +1474,16 @@ gnomemeeting_init_pref_window_audio_codecs (GtkWidget *window,
   GtkTreeViewColumn *column = NULL;
   GtkCellRenderer *renderer = NULL;                        
                                                        
+  BOOL use_quicknet = FALSE;
+  BOOL soft_codecs_supported = FALSE;
+  
+  GmPrefWindow *pw = NULL;
 
-  /* Get the data */
-  GmPrefWindow *pw = GnomeMeeting::Process ()->GetPrefWindow ();
-
+  
+  pw = GnomeMeeting::Process ()->GetPrefWindow ();
+  ep = GnomeMeeting::Process ()->Endpoint ();
 
+  
   /* Packing widgets */
   subsection =
     gnome_prefs_subsection_new (window, container,
@@ -1552,8 +1600,9 @@ gnomemeeting_init_pref_window_audio_codecs (GtkWidget *window,
   gtk_widget_show_all (frame);
 
 
-  /* Here we finally add the codecs in the order they are in the config */
-  gnomemeeting_codecs_list_build (pw->codecs_list_store);
+  gnomemeeting_codecs_list_build (pw->codecs_list_store,
+				  use_quicknet,
+				  soft_codecs_supported);
 
 
   /* Here we add the audio codecs options */
@@ -1563,9 +1612,9 @@ gnomemeeting_init_pref_window_audio_codecs (GtkWidget *window,
 
   /* Translators: the full sentence is Automatically adjust jitter buffer
      between X and Y ms */
-  gnome_prefs_range_new (subsection, _("Automatically adjust _jitter buffer between"), NULL, _("and"), NULL, _("ms"), AUDIO_SETTINGS_KEY "min_jitter_buffer", AUDIO_SETTINGS_KEY "max_jitter_buffer", _("The minimum jitter buffer size for audio reception (in ms)."), _("The maximum jitter buffer size for audio reception (in ms)."), 20.0, 20.0, 1000.0, 1000.0, 1.0, 0);
+  gnome_prefs_range_new (subsection, _("Automatically adjust _jitter buffer between"), NULL, _("and"), NULL, _("ms"), AUDIO_CODECS_KEY "minimum_jitter_buffer", AUDIO_CODECS_KEY "maximum_jitter_buffer", _("The minimum jitter buffer size for audio reception (in ms)."), _("The maximum jitter buffer size for audio reception (in ms)."), 20.0, 20.0, 1000.0, 1000.0, 1.0, 0);
   
-  gnome_prefs_toggle_new (subsection, _("Enable silence _detection"), AUDIO_SETTINGS_KEY "sd", _("If enabled, use silence detection with the GSM and G.711 codecs."), 1);
+  gnome_prefs_toggle_new (subsection, _("Enable silence _detection"), AUDIO_CODECS_KEY "enable_silence_detection", _("If enabled, use silence detection with the GSM and G.711 codecs."), 1);
 }
                                                                                
 
@@ -1587,10 +1636,9 @@ gnomemeeting_init_pref_window_video_codecs (GtkWidget *window,
 
   
   /* Add fields */
-  gnome_prefs_toggle_new (subsection, _("Enable video _transmission"), VIDEO_SETTINGS_KEY "enable_video_transmission", _("If enabled, video is transmitted during a call."), 0);
+  gnome_prefs_toggle_new (subsection, _("Enable video _transmission"), VIDEO_CODECS_KEY "enable_video_transmission", _("If enabled, video is transmitted during a call."), 0);
 
-  pw->vid_re =
-    gnome_prefs_toggle_new (subsection, _("Enable video _reception"), VIDEO_SETTINGS_KEY "enable_video_reception", _("If enabled, allows video to be received during a call."), 1);
+  gnome_prefs_toggle_new (subsection, _("Enable video _reception"), VIDEO_CODECS_KEY "enable_video_reception", _("If enabled, allows video to be received during a call."), 1);
 
 
   /* H.261 Settings */
@@ -1598,7 +1646,7 @@ gnomemeeting_init_pref_window_video_codecs (GtkWidget *window,
 					   _("Bandwidth Control"), 1, 1);
 
   /* Translators: the full sentence is Maximum video bandwidth of X KB/s */
-  gnome_prefs_spin_new (subsection, _("Maximum video _bandwidth of"), VIDEO_SETTINGS_KEY "maximum_video_bandwidth", _("The maximum video bandwidth in kbytes/s. The video quality and the number of transmitted frames per second will be dynamically adjusted above their minimum during calls to try to minimize the bandwidth to the given value."), 2.0, 100.0, 1.0, 0, _("KB/s"), true);
+  gnome_prefs_spin_new (subsection, _("Maximum video _bandwidth of"), VIDEO_CODECS_KEY "maximum_video_bandwidth", _("The maximum video bandwidth in kbytes/s. The video quality and the number of transmitted frames per second will be dynamically adjusted above their minimum during calls to try to minimize the bandwidth to the given value."), 2.0, 100.0, 1.0, 0, _("KB/s"), true);
   
 
   /* Advanced quality settings */
@@ -1607,14 +1655,14 @@ gnomemeeting_init_pref_window_video_codecs (GtkWidget *window,
 				_("Advanced Quality Settings"), 3, 1);
   
   /* Translators: the full sentence is Keep a minimum video quality of X % */
-  gnome_prefs_spin_new (subsection, _("Keep a minimum video _quality of"), VIDEO_SETTINGS_KEY "tr_vq", _("The minimum transmitted video quality to keep when trying to minimize the used bandwidth:  choose 100% on a LAN for the best quality, 1% being the worst quality."), 1.0, 100.0, 1.0, 0, _("%"), true);
+  gnome_prefs_spin_new (subsection, _("Keep a minimum video _quality of"), VIDEO_CODECS_KEY "transmitted_video_quality", _("The minimum transmitted video quality to keep when trying to minimize the used bandwidth:  choose 100% on a LAN for the best quality, 1% being the worst quality."), 1.0, 100.0, 1.0, 0, _("%"), true);
 
   /* Translators: the full sentence is Transmit at least X frames per second */
-  gnome_prefs_spin_new (subsection, _("Transmit at least"), VIDEO_SETTINGS_KEY "tr_fps", _("The minimum number of video frames to transmit each second when trying to minimize the bandwidth."), 1.0, 30.0, 1.0, 1, _("_frames per second"), true);
+  gnome_prefs_spin_new (subsection, _("Transmit at least"), VIDEO_CODECS_KEY "transmitted_fps", _("The minimum number of video frames to transmit each second when trying to minimize the bandwidth."), 1.0, 30.0, 1.0, 1, _("_frames per second"), true);
 				 
   /* Translators: the full sentence is Transmit X background blocks with each
      frame */
-  gnome_prefs_spin_new (subsection, _("Transmit"), VIDEO_SETTINGS_KEY "tr_ub", _("Choose the number of blocks (that have not changed) transmitted with each frame. These blocks fill in the background."), 1.0, 99.0, 1.0, 2, _("background _blocks with each frame"), true);
+  gnome_prefs_spin_new (subsection, _("Transmit"), VIDEO_CODECS_KEY "transmitted_background_blocks", _("Choose the number of blocks (that have not changed) transmitted with each frame. These blocks fill in the background."), 1.0, 99.0, 1.0, 2, _("background _blocks with each frame"), true);
 }
 
 
@@ -1680,31 +1728,39 @@ gnomemeeting_pref_window_new (GmPrefWindow *pw)
   gnomemeeting_init_pref_window_directories (window, container);
   gtk_widget_show_all (GTK_WIDGET (container));
   
+  container = gnome_prefs_window_subsection_new (window, _("Call Options"));
+  gnomemeeting_init_pref_window_call_options (window, container);
+  gtk_widget_show_all (GTK_WIDGET (container));
+
+  container = gnome_prefs_window_subsection_new (window, _("NAT Settings"));
+  gnomemeeting_init_pref_window_nat (window, container);
+  gtk_widget_show_all (GTK_WIDGET (container));
+
   container = gnome_prefs_window_subsection_new (window,
 						 _("Sound Events"));
   gnomemeeting_init_pref_window_sound_events (window, container);
   gtk_widget_show_all (GTK_WIDGET (container));
-  
-  container = gnome_prefs_window_subsection_new (window, _("Call Forwarding"));
-  gnomemeeting_init_pref_window_call_forwarding (window, container);
-  gtk_widget_show_all (GTK_WIDGET (container));
-  
 
   gnome_prefs_window_section_new (window, _("H.323 Settings"));
   container = gnome_prefs_window_subsection_new (window,
 						 _("Advanced Settings"));
   gnomemeeting_init_pref_window_h323_advanced (window, container);          
   gtk_widget_show_all (GTK_WIDGET (container));
-  
+
+  container = gnome_prefs_window_subsection_new (window, _("Call Forwarding"));
+  gnomemeeting_init_pref_window_call_forwarding (window, container);
+  gtk_widget_show_all (GTK_WIDGET (container));
+
   container = gnome_prefs_window_subsection_new (window,
 						 _("Gatekeeper Settings"));
   gnomemeeting_init_pref_window_gatekeeper (window, container);          
   gtk_widget_show_all (GTK_WIDGET (container));
-  
-  container = gnome_prefs_window_subsection_new (window, _("NAT Settings"));
-  gnomemeeting_init_pref_window_nat (window, container);
+
+  container = gnome_prefs_window_subsection_new (window,
+						 _("Gateway / Proxy Settings"));
+  gnomemeeting_init_pref_window_gateway (window, container);          
   gtk_widget_show_all (GTK_WIDGET (container));
-  
+
   gnome_prefs_window_section_new (window, _("Codecs"));
 
   container = gnome_prefs_window_subsection_new (window, _("Audio Codecs"));
